
	/* Center for American Progress - Higher Education 
		
		Replication Code for: 
		"Gone and Not Forgiven: Exploring the Loan 
			Forgiveness Costs of Gainful Employment Programs"
		
		Authors: Ben Miller, CJ Libassi
		Last Edit: 3.30.17
		
		**MAIN ANALYSIS FILE**
	*/
	
	*Boilerplate
	set more off
	clear all
	set maxvar 32000
	set seed 1234570
	capture log close 
	set rmsg on 
	
	/******
	
		READ ME FIRST: 
		
			For this code to work, you must:
			
				-Keep all downloaded files in the same folder
				-Change the path stored in the global variable "ge_data" to the 
					path where you stored that folder from "P:\YOUR\PATH\HERE\"
					Note: Make sure to include that final \
				-Install user written commands:	
						grc1leg
						binscatter
						tabstatmat
						
				-Install user written scheumes:
						burd
					
			A small warning: Code from line 47 to 1052 can take a long time to run.
				Once you have run it once successfully, you can comment it out by
				adding a / before the * in line 56 for any future code runs. 
					
	
	*******/
	*Globals
	global ge_data "P:\YOUR\PATH\HERE\Replication Folder\"  
	
	*Open Log File
	log using "${ge_data}CAP_ge_log.smcl", replace 
	
	timer on 1 

	
	*Next do GE data
	import excel "${ge_data}GE-DMYR-2015-Final-Rates.xls", clear firstrow 
	
		*Clean up variable names
		rename (InstitutionCodesixdigitOPEI InstitutionName City State Zip ///
		InstitutionType CIPCode CIPName CredentialLevel OfficialProgramPassZoneFail ///
		AppealStatus DebttoEarningsAnnualRate DebttoEarningsAnnualRateNum ///
		DebttoEarningsAnnualRateDen DebttoEarningsAnnualRatePas ///
		DebttoEarningsDiscretionaryI Q R S DebttoEarningsTransitionalRa U V W ///
		DebttoEarningsTransitionalDi Y Z AA MeanAnnualEarnings MedianAnnualEarnings) ///
		(opeid inst_nm city state zip type_control cipcode cipname level ///
		pass_zone_fail appeal_status debt_to_earn_annual_rate ///
		debt_to_earn_annual_num debt_to_earn_annual_denom d_to_e_annual_fpz ///
		debt_to_earn_disc_rate debt_to_earn_disc_num debt_to_earn_disc_denom ///
		d_to_e_disc_fpz debt_to_earn_trans_rate debt_to_earn_trans_num ///
		debt_to_earn_trans_denom d_to_e_trans_fpz debt_to_earn_trans_disc_rate ///
		debt_to_earn_trans_disc_num debt_to_earn_trans_disc_denom ///
		d_to_e_trans_disc_fpz mean_earnings med_earnings)
	
	describe
	
		
		*Clean Level Codes before analysis begins
		encode level, gen(level_code)
		
		
		label define level_codes 1 "Undergrad Cert" 2 "Associates Degree" ///
					3 "Bachelor's Degree" 4 "Post-Baccalaureate Cert" ///
					5 "Master's Degree" 6 "Doctoral Degree" ///
					7 "First Professional Degree" 8 "Graduate Certificate" 
		
		destring level_code, replace
		
		
		*Clean up the dataset a bit 
		
		*Drop labels
		label drop level_code
		
		*Create a temp variable to move the codes
		gen test = level_code 
		
		*Destring the new variable
		tostring test, replace 
		
		*Drop the original
		drop level_code 
		
		*Turn temp variable into a string with a zero at the front
		replace test= "0"+test
		
		*Rename it to level code
		rename test level_code 
		
		*Create a unique combined OPEID, CIPCODE, LEVEL_CODE id
		gen opciplev = opeid + cipcode + level_code
		
		*Save Imported Data in Stata Format 
		saveold "${ge_data}CAP_ge_base_data.dta", replace 
		
		*Merge on student counts from earnings data release in 2016
		preserve 
		
		import excel "${ge_data}GE_SSA_Earnings_2014.xls", firstrow clear 
		
			rename *, lower 
			
			rename (credentiallevelcode verifiedstudentcount) (level_code stu_count)
			
			*Create a unique combined OPEID, CIPCODE, LEVEL_CODE id
			gen opciplev = opeid + cipcode + level_code
			
			keep opciplev stu_count
			
			saveold "${ge_data}GE_SSA_Earnings_student_count.dta", replace 
			
		restore
	
		*Merge on student count 
		merge 1:1 opciplev using "${ge_data}GE_SSA_Earnings_student_count.dta"
			
			keep if _merge==3 
			drop _merge
		
		saveold "${ge_data}CAP_ge_base_data.dta", replace 

		destring level_code, replace 

		keep if inlist(level_code, 5, 6, 7, 8)
	
	
	*Build Out Our Version of the FSA Repayment Estimator
	
		/* 
			Assumptions from FSA Repayment Estimator: 
				-Paying continuously
				-5% growth in income each year 
				-Family size will remain the same
				-Poverty guidelines increase based on CBO's estimation of inflation
				-Stable interest rate 

	
	*First Calculate Standard 10yr payment 
	
		*Backing Out Total Loan Balance from Annual Payments
			* i = annual interest rate
			* n = number of years
			* t = number of payments per year 
			* p = annual payment 
		
	
	*Step 1: Calculate Total Loan Balance of loan, set those 
				without any starting principal balance to missing

			We do this so that we can find the 
			standard 10yr payment & calculate forgiveness
		*/
		
	gen principal_balance =  .
	
		replace principal_balance = ((1-(1+(.068/12))^-(10*12))*(debt_to_earn_disc_num/12))/(.068/12) ///
			if (level_code==1 | level_code==2) & debt_to_earn_disc_num>0 
		replace principal_balance = ((1-(1+(.068/12))^-(15*12))*(debt_to_earn_disc_num/12))/(.068/12) ///
			if (level_code==3 | level_code==4 | level_code==5) & debt_to_earn_disc_num>0 
		replace principal_balance = ((1-(1+(.068/12))^-(20*12))*(debt_to_earn_disc_num/12))/(.068/12) ///
			if (level_code==6 | level_code==7 | level_code==8) & debt_to_earn_disc_num>0 

	*Step 2: Calculate 10-yr standard payment for each program
				* A = P*((r(1+r)^n)/((1+r)^n)-1)	
	gen standard_payment = principal_balance*((.00566667*(1+.00566667)^120))/(((1+.00566667)^120)-1)
		
		*Replace if payment isn't at least the minimum payment of $50
		replace standard_payment = 50 if standard_payment>0 & standard_payment<50 ///
										& !missing(standard_payment) 
			
		*Figure out the annual payment
		gen annual_payment = standard_payment*12 
			
			/*Replace annual payment with the principal balance if the minimum 
				annual payment (12*50=$600) is greater than original principal 
				balance	*/
			replace annual_payment = principal_balance if principal_balance<600 

	
	*Step 3: Calculate Discretionary Income in base year (2015), 
		*to serve as basis for PAYE payment calc
		
		*Earnings in 2014 for 2015 payment year  
		gen earnings_year_3 = max(med_earnings, mean_earnings) 
		
			*Calculate 150% of the federal poverty line
			local fpl_150 = 11770*1.5 
			
			*Calculate discretionary median earnings
			gen disc_med_earn_year_3 = .
				replace disc_med_earn_year_3 = 0 if earnings <= `fpl_150'
				replace disc_med_earn_year_3 = earnings - `fpl_150' ///
					if earnings > `fpl_150'
				
		*Set Earnings Appreciation Rate
		local earn_grow = .05
		local earn_grow_factor = 1+`earn_grow'
		
	
	*Step 4: Calculation Income In Years Outside the Base Year
	
		/* 
			Work backward and forward from base year, assuming a 5% growth in 
			income each year, which is what the FSA Repayment calculator 
			assumes. We make the assumption that all repayers enter repayment 
			in January 2013. 
		*/
		
		
		*First moving backward 
		
		*2013 Earnings for 2014 payment year
		gen earnings_year_2 = earnings_year_3/`earn_grow_factor'
		
			*Calculate 150% of the federal poverty line
			local fpl_150 = 11670*1.5 
			
		*Calculate discretionary median earnings
		gen disc_med_earn_year_2 = .
			replace disc_med_earn_year_2 = 0 if earnings_year_2 <= `fpl_150'
			replace disc_med_earn_year_2 = earnings_year_2 - `fpl_150' ///
				if earnings_year_2 > `fpl_150'	

		*2012 Earnings for 2013 payment year
		gen earnings_year_1 = earnings_year_2/`earn_grow_factor'
		
			*Calculate 150% of the federal poverty line
			local fpl_150 = 11490*1.5 
			
		*Calculate discretionary median earnings
		gen disc_med_earn_year_1 = .
			replace disc_med_earn_year_1 = 0 if earnings_year_1 <= `fpl_150'
			replace disc_med_earn_year_1 = earnings_year_1 - `fpl_150' ///
				if earnings_year_1 > `fpl_150'	

	
		*Now Go Forward in Time with Actual Poverty Level for Years that we have it for
		
		*2015 earnings for 2016 payment year (real poverty level)
		gen earnings_year_4 = earnings_year_3*`earn_grow_factor'
		
			*Calculate 150% of the federal poverty line
			local fpl_150 = 11880*1.5 
			
		*Calculate discretionary median earnings
		gen disc_med_earn_year_4 = .
				replace disc_med_earn_year_4 = 0 if earnings_year_4 <= `fpl_150'
				replace disc_med_earn_year_4 = earnings_year_4 - `fpl_150' if earnings_year_4 > `fpl_150'
				
		*2016 earning for 2017 payment year (real poverty level)
		gen earnings_year_5 = earnings_year_4*`earn_grow_factor'
		
			*Calculate 150% of the federal poverty line
			local fpl_150 = 12060*1.5 
			
		*Calculate discretionary median earnings
		gen disc_med_earn_year_5 = .
				replace disc_med_earn_year_5 = 0 if earnings_year_5 <= `fpl_150'
				replace disc_med_earn_year_5 = earnings_year_5 - `fpl_150' if earnings_year_5 > `fpl_150'
				
		/*Now loop through going forward, increasing income by 5% and inflating poverty level
				by 2% every year */
		
		*Set the starting poverty level
		local pov_level = 12060 
		
		forvalues i = 6/25{ 
		
			*Increase the poverty level by 2%
			local pov_level = `pov_level'*1.02 
		
			*Calculate year last year
			local last_year= `i'-1
			
			*Grow median earnings 
			gen earnings_year_`i' = earnings_year_`last_year'*`earn_grow_factor'
			
				*Calculate 150% of the federal poverty line
				local fpl_150 = `pov_level'*1.5 
			
			*Calculate discretionary median earnings
			gen disc_med_earn_year_`i' = .
				replace disc_med_earn_year_`i' = 0 if earnings_year_`i' <= `fpl_150'
				replace disc_med_earn_year_`i' = earnings_year_`i' - `fpl_150' if earnings_year_`i' > `fpl_150'	
			}
	
		*Determine if there is a partial financial hardship by comparing 
			*standard payment to 10% of Discretionary Income
			
		*Set blank variable
		gen interest_month_1_year_1 = 0
				
			*Generate interest acruals for 31 day months
			replace interest_month_1_year_1 = principal_balance*31*(.068/365) ///
					if 1==1 | 1==3 | 1==5 | 1==7 | ///
							1==8 | 1==10 | 1==12  
								
			*Generate interest acruals for 30 day months			
			replace interest_month_1_year_1 = principal_balance*30*(.068/365) ///
						if 1==4 | 1==6 | 1==9 | 1==11 
			
			*Generate interest acruals for February
			replace interest_month_1_year_1 = principal_balance*28*(.068/365) ///
						if 1==2 

			*Add interest for this month to interest principal 
			egen amount_owed_1_year_1 = rowtotal(interest_month_1_year_1 principal_balance)
				
			*Calculate 10% of discretionary income, divide by 12
			gen ten_perc_1_year_1 = (disc_med_earn_year_1*.1)/12
					
			*Calculate Repaye Payment as minimum of ten percent and amount left to pay
			gen repaye_payment_month_1_year_1 = min(ten_perc_1_year_1, amount_owed_1_year_1) 
				replace repaye_payment_month_1_year_1=. if principal_balance==.
			
			*Calculate Repaye Payment as max of amoritzed payment and $50, which is the min payment
			gen standard_paymennt_month_1_year_1 = max(50, standard_payment) 
				
				*Create a fix if the outstanding balance is less than $50
				replace standard_paymennt_month_1_year_1 = principal_balance if principal_balance<50
		
			*Create an indicator for partial financial hardship if REPAYE payment would be lower than standard payment
			gen part_fin_hard = repaye_payment_month_1_year_1<standard_paymennt_month_1_year_1 ///
					& !missing(standard_paymennt_month_1_year_1) & !missing(principal_balance)  
			
			*Drop all of these variables so the loop doesn't get screwed up 
			drop interest_month_1_year_1 amount_owed_1_year_1 ten_perc_1_year_1 ///
					repaye_payment_month_1_year_1 standard_paymennt_month_1_year_1 
			
	
	/*Step 5: With Loops 
	
			a) Calculate Pay-as-you-earn payment for each year 
			b) Calculate monthly interest accruals
			c) Calculate portion of actual payment that is interest & principal
			d) Calculate interest running accumulation across months 
			e) Calculate monthly principal paydown
	
	*/
		*Set up running calculation of the principal balance & accumulating interest
		gen rp_running_princ_bal = principal_balance 
		gen std_running_princ_bal = principal_balance 
		gen act_running_princ_bal = principal_balance 
	
		gen rp_accum_excess_interest = 0 
		gen std_accum_excess_interest = 0 
		gen act_accum_excess_interest = 0 
	
		*Loop through years
		forvalues year = 1/25{ 
		
			*Loop through months
			forvalues month = 1/12{
		
				*Check Principal Balance at beginning of month
				gen rp_running_princ_bal_`month'_`year' = rp_running_princ_bal
				gen std_running_princ_bal_`month'_`year' = std_running_princ_bal
				gen act_running_princ_bal_`month'_`year' = act_running_princ_bal
				
				*A) Calculate Interest Amount Acrrued in This Month
				
				*REPAYE 
				*Set blank variable
				gen rp_interest_month_`month'_year_`year' = 0
				
					*Generate interest acruals for 31 day months
					replace rp_interest_month_`month'_year_`year' = rp_running_princ_bal*31*(.068/365) ///
							if `month'==1 | `month'==3 | `month'==5 | `month'==7 | ///
								`month'==8 | `month'==10 | `month'==12  
								
					*Generate interest acruals for 30 day months			
					replace rp_interest_month_`month'_year_`year' = rp_running_princ_bal*30*(.068/365) ///
							if `month'==4 | `month'==6 | `month'==9 | `month'==11 
			
					*Generate interest acruals for February
					replace rp_interest_month_`month'_year_`year' = rp_running_princ_bal*28*(.068/365) ///
							if `month'==2 
							
				*STD 
				*Set blank variable
				gen std_interest_month_`month'_year_`year' = 0
				
					*Generate interest acruals for 31 day months
					replace std_interest_month_`month'_year_`year' = std_running_princ_bal*31*(.068/365) ///
							if `month'==1 | `month'==3 | `month'==5 | `month'==7 | ///
								`month'==8 | `month'==10 | `month'==12  
								
					*Generate interest acruals for 30 day months			
					replace std_interest_month_`month'_year_`year' = std_running_princ_bal*30*(.068/365) ///
							if `month'==4 | `month'==6 | `month'==9 | `month'==11 
			
					*Generate interest acruals for February
					replace std_interest_month_`month'_year_`year' = std_running_princ_bal*28*(.068/365) ///
							if `month'==2 
							
				*Actual 
				*Set blank variable
				gen act_interest_month_`month'_year_`year' = 0
				
					*Generate interest acruals for 31 day months
					replace act_interest_month_`month'_year_`year' = act_running_princ_bal*31*(.068/365) ///
							if `month'==1 | `month'==3 | `month'==5 | `month'==7 | ///
								`month'==8 | `month'==10 | `month'==12  
								
					*Generate interest acruals for 30 day months			
					replace act_interest_month_`month'_year_`year' = act_running_princ_bal*30*(.068/365) ///
							if `month'==4 | `month'==6 | `month'==9 | `month'==11 
			
					*Generate interest acruals for February
					replace act_interest_month_`month'_year_`year' = act_running_princ_bal*28*(.068/365) ///
							if `month'==2 
							
				*B) Adjust Accumulated Interest So All Unpaid Interest Is Lumped 
					*into one amount that must be paid off before touching principal
				
					*REPAYE
					*Add this month's interest to the running accumulated interest 
					egen rp_accum_int_month_`month'_year_`year' = rowtotal(rp_accum_excess_interest rp_interest_month_`month'_year_`year')
					
					replace rp_accum_excess_interest = rp_accum_int_month_`month'_year_`year'
					
					*STD
					*Add this month's interest to the running accumulated interest 
					egen std_accum_int_month_`month'_year_`year' = rowtotal(std_accum_excess_interest std_interest_month_`month'_year_`year')
					
					replace std_accum_excess_interest = std_accum_int_month_`month'_year_`year'
					
					*Actual
					*Add this month's interest to the running accumulated interest 
					egen act_accum_int_month_`month'_year_`year' = rowtotal(act_accum_excess_interest act_interest_month_`month'_year_`year')
					
					replace act_accum_excess_interest = act_accum_int_month_`month'_year_`year'
					
				*C) Calculate a total amount left to be paid (principal & interest) that cannot be exceded with any payment
				
					*REPAYE
					egen rp_total_balance_`month'_`year' = rowtotal(rp_running_princ_bal rp_accum_excess_interest)
					
					*STD
					egen std_total_balance_`month'_`year' = rowtotal(std_running_princ_bal std_accum_excess_interest)
					

				*D) Calculate REPAYE Payment and Breakdown 
				
					*REPAYE amount = minimum of 10% of discretionary income in that year or total balance as of that month
				
					*Calculate 10% of discretionary income, divide by 12
					gen ten_perc_`month'_year_`year' = (disc_med_earn_year_`year'*.1)/12
					
					*Calculate REPAYE Payment as minimum of ten percent and amount left to pay
					gen repaye_payment_month_`month'_year_`year' = min(ten_perc_`month'_year_`year', rp_total_balance_`month'_`year')  
					
					*REPAYE payment breakdown:
						
					*First calculate interest part by taking the minimum of the outstanding interest and the REPAYE payment
					gen repaye_int_pt_`month'_`year' = min(rp_accum_excess_interest, repaye_payment_month_`month'_year_`year')
						
					*Then calculate principal part by calculating the remaining payment not going toward interest
					gen repaye_minus_int_`month'_`year' = repaye_payment_month_`month'_year_`year'-rp_interest_month_`month'_year_`year'
					gen repaye_princ_pt_`month'_`year' = max(repaye_minus_int_`month'_`year', 0)
						
					*Then calculate the net change in interest as interest accumulated less interested paid 
					gen rp_interest_change_`month'_`year' = -1*(repaye_int_pt_`month'_`year')+(rp_interest_month_`month'_year_`year'-repaye_int_pt_`month'_`year')
					
						*Make adjustment for the REPAYE interest subsidy
						replace  rp_interest_change_`month'_`year' =  rp_interest_change_`month'_`year'/2 if rp_interest_change_`month'_`year'>0 & !missing(rp_interest_change_`month'_`year')
						
						
				*E) Calculate Standard Payment and Breakdown 
					
					*Calculate final standard payment as minimum of standard payment and amount left to pay 
					gen std_payment_`month'_`year' = min(standard_payment, std_total_balance_`month'_`year') 
					
					*First calculate interest part by taking the minimum of the outstanding interest and the standard payment
					gen std_int_pt_`month'_`year' = min(std_interest_month_`month'_year_`year', std_payment_`month'_`year')
						
					*Then calculate principal part by calculating the remaining payment not going toward interest
					gen std_minus_int_`month'_`year' = std_payment_`month'_`year'-std_interest_month_`month'_year_`year'
					gen std_princ_pt_`month'_`year' = max(std_minus_int_`month'_`year', 0)
					
					*Then calculate the net change in interest as interest accumulated less interested paid (in standard situation, interest never goes unpaid)
					gen std_interest_change_`month'_`year' = -1*(std_int_pt_`month'_`year')+(std_interest_month_`month'_year_`year'-std_int_pt_`month'_`year')
									
					
				*F) Calculate True Payment & True Payment Parts & True Interest Change & True Interest Forgiveness
				
					*If there's a hardship, assign the REPAYE payment, if not then standard payment
					gen actual_payment_`month'_`year' = std_payment_`month'_`year' if part_fin_hard==0
					replace actual_payment_`month'_`year' = repaye_payment_month_`month'_year_`year' if part_fin_hard
					
					*If there's a hardship, assign REPAYE interest part, if not standard interest part 
					gen actual_int_pt_`month'_`year' = std_int_pt_`month'_`year' if part_fin_hard==0 
					replace actual_int_pt_`month'_`year' = repaye_int_pt_`month'_`year' if part_fin_hard 
				
					*If there's a hardship, assign REPAYE principal part, if not standard principal part
					gen actual_princ_pt_`month'_`year' = std_princ_pt_`month'_`year' if part_fin_hard==0 
					replace actual_princ_pt_`month'_`year' = repaye_princ_pt_`month'_`year' if part_fin_hard  
				
					*If there's a hardship, assign REPAYE interest change, otherwise assign standard interest change 
					gen actual_interest_change_`month'_`year' = std_interest_change_`month'_`year' if part_fin_hard==0 
					replace actual_interest_change_`month'_`year' = rp_interest_change_`month'_`year' if part_fin_hard
					
					*Capture interest forgiven at this moment
					gen act_interest_forgiven_`month'_`year' = actual_interest_change_`month'_`year'/2 if rp_interest_change_`month'_`year'>0 & !missing(rp_interest_change_`month'_`year') & part_fin_hard
						
					
					**** Build in a check to make sure payment parts add up to full payment
					gen pts_not_equal_flag_`month'_`year' = round(actual_payment_`month'_`year')!=round(actual_int_pt_`month'_`year'+actual_princ_pt_`month'_`year')
					
				*G) Draw down the prinicipal & interest balances separately for REPAYE, Standard & Actual 
				
					*REPAYE 
					
					*Principal draw down. Take principal amount and subtract out principal part of payment
					replace rp_running_princ_bal  = rp_running_princ_bal-repaye_princ_pt_`month'_`year'
					
						*Store the principal balance after payment 
						gen rp_post_rprinc_`month'_`year' = rp_running_princ_bal 
					
					*Interest draw down. Take accumulated interest amount and add net interest change
					replace rp_accum_excess_interest = rp_accum_excess_interest+rp_interest_change_`month'_`year'
					
						*Store the interest balance after payment 
						gen rp_post_aint_month_`month'_year_`year' = rp_accum_excess_interest
						
						
					*Standard
						
					*Principal draw down. Take principal amount and subtract out principal part of payment
					replace std_running_princ_bal  = std_running_princ_bal-std_princ_pt_`month'_`year'
					
						*Store the principal balance after payment 
						gen std_post_rprinc_`month'_`year' = std_running_princ_bal 
					
					*Interest draw down. Take accumulated interest amount and add net interest change
					replace std_accum_excess_interest = std_accum_excess_interest+std_interest_change_`month'_`year'
					
						*Store the interest balance after payment 
						gen std_post_aint_month_`month'_year_`year' = std_accum_excess_interest
						
						
						
					*Actual
					
					*Principal draw down. Take principal amount and subtract out principal part of payment
					replace act_running_princ_bal  = act_running_princ_bal-actual_princ_pt_`month'_`year'
					
						*Store the principal balance after payment 
						gen act_post_rprinc_`month'_`year' = act_running_princ_bal 
					
					*Interest draw down. Take accumulated interest amount and add net interest change
					replace act_accum_excess_interest = act_accum_excess_interest+actual_interest_change_`month'_`year'
					
						*Store the interest balance after payment 
						gen act_post_aint_month_`month'_year_`year' = act_accum_excess_interest
				
			
			}
		}
		
		*Drop unnecessary variables to speed up reshape
		drop opeid city state zip cipname type_control appeal_status ///
		debt_to_earn_disc_rate debt_to_earn_disc_num debt_to_earn_disc_denom ///
		d_to_e_disc_fpz debt_to_earn_trans_rate debt_to_earn_trans_num ///
		debt_to_earn_trans_denom d_to_e_trans_fpz debt_to_earn_trans_disc_rate ///
		debt_to_earn_trans_disc_num debt_to_earn_trans_disc_denom d_to_e_trans_disc_fpz 
		
		*Reshape to long by year, leaving months wide
		reshape long earnings_year_ disc_med_earn_year_ ///
			 rp_running_princ_bal_1_ ///
			 std_running_princ_bal_1_ act_running_princ_bal_1_ rp_interest_month_1_year_ /// 
			 std_interest_month_1_year_  act_interest_month_1_year_ rp_accum_int_month_1_year_ ///
			 std_accum_int_month_1_year_ act_accum_int_month_1_year_ rp_total_balance_1_ ///
			 std_total_balance_1_ ten_perc_1_year_ repaye_payment_month_1_year_ repaye_int_pt_1_ ///
			 repaye_minus_int_1_ repaye_princ_pt_1_ rp_interest_change_1_ std_payment_1_ ///
			 std_int_pt_1_ std_minus_int_1_ std_princ_pt_1_ std_interest_change_1_ ///
			 actual_payment_1_ actual_int_pt_1_ actual_princ_pt_1_ actual_interest_change_1_ ///
			 pts_not_equal_flag_1_ rp_post_rprinc_1_ rp_post_aint_month_1_year_ ///
			 std_post_rprinc_1_ std_post_aint_month_1_year_ act_post_rprinc_1_ ///
			 act_post_aint_month_1_year_ act_interest_forgiven_1_ ///
			 rp_running_princ_bal_2_ ///
			 std_running_princ_bal_2_ act_running_princ_bal_2_ rp_interest_month_2_year_ /// 
			 std_interest_month_2_year_  act_interest_month_2_year_ rp_accum_int_month_2_year_ ///
			 std_accum_int_month_2_year_ act_accum_int_month_2_year_ rp_total_balance_2_ ///
			 std_total_balance_2_ ten_perc_2_year_ repaye_payment_month_2_year_ repaye_int_pt_2_ ///
			 repaye_minus_int_2_ repaye_princ_pt_2_ rp_interest_change_2_ std_payment_2_ ///
			 std_int_pt_2_ std_minus_int_2_ std_princ_pt_2_ std_interest_change_2_ ///
			 actual_payment_2_ actual_int_pt_2_ actual_princ_pt_2_ actual_interest_change_2_ ///
			 pts_not_equal_flag_2_ rp_post_rprinc_2_ rp_post_aint_month_2_year_ ///
			 std_post_rprinc_2_ std_post_aint_month_2_year_ act_post_rprinc_2_ ///
			 act_post_aint_month_2_year_ act_interest_forgiven_2_ ///
			 rp_running_princ_bal_3_ ///
			 std_running_princ_bal_3_ act_running_princ_bal_3_ rp_interest_month_3_year_ /// 
			 std_interest_month_3_year_  act_interest_month_3_year_ rp_accum_int_month_3_year_ ///
			 std_accum_int_month_3_year_ act_accum_int_month_3_year_ rp_total_balance_3_ ///
			 std_total_balance_3_ ten_perc_3_year_ repaye_payment_month_3_year_ repaye_int_pt_3_ ///
			 repaye_minus_int_3_ repaye_princ_pt_3_ rp_interest_change_3_ std_payment_3_ ///
			 std_int_pt_3_ std_minus_int_3_ std_princ_pt_3_ std_interest_change_3_ ///
			 actual_payment_3_ actual_int_pt_3_ actual_princ_pt_3_ actual_interest_change_3_ ///
			 pts_not_equal_flag_3_ rp_post_rprinc_3_ rp_post_aint_month_3_year_ ///
			 std_post_rprinc_3_ std_post_aint_month_3_year_ act_post_rprinc_3_ ///
			 act_post_aint_month_3_year_ act_interest_forgiven_3_ ///
			 rp_running_princ_bal_4_ ///
			 std_running_princ_bal_4_ act_running_princ_bal_4_ rp_interest_month_4_year_ /// 
			 std_interest_month_4_year_  act_interest_month_4_year_ rp_accum_int_month_4_year_ ///
			 std_accum_int_month_4_year_ act_accum_int_month_4_year_ rp_total_balance_4_ ///
			 std_total_balance_4_ ten_perc_4_year_ repaye_payment_month_4_year_ repaye_int_pt_4_ ///
			 repaye_minus_int_4_ repaye_princ_pt_4_ rp_interest_change_4_ std_payment_4_ ///
			 std_int_pt_4_ std_minus_int_4_ std_princ_pt_4_ std_interest_change_4_ ///
			 actual_payment_4_ actual_int_pt_4_ actual_princ_pt_4_ actual_interest_change_4_ ///
			 pts_not_equal_flag_4_ rp_post_rprinc_4_ rp_post_aint_month_4_year_ ///
			 std_post_rprinc_4_ std_post_aint_month_4_year_ act_post_rprinc_4_ ///
			 act_post_aint_month_4_year_ act_interest_forgiven_4_ ///
			 rp_running_princ_bal_5_ ///
			 std_running_princ_bal_5_ act_running_princ_bal_5_ rp_interest_month_5_year_ /// 
			 std_interest_month_5_year_  act_interest_month_5_year_ rp_accum_int_month_5_year_ ///
			 std_accum_int_month_5_year_ act_accum_int_month_5_year_ rp_total_balance_5_ ///
			 std_total_balance_5_ ten_perc_5_year_ repaye_payment_month_5_year_ repaye_int_pt_5_ ///
			 repaye_minus_int_5_ repaye_princ_pt_5_ rp_interest_change_5_ std_payment_5_ ///
			 std_int_pt_5_ std_minus_int_5_ std_princ_pt_5_ std_interest_change_5_ ///
			 actual_payment_5_ actual_int_pt_5_ actual_princ_pt_5_ actual_interest_change_5_ ///
			 pts_not_equal_flag_5_ rp_post_rprinc_5_ rp_post_aint_month_5_year_ ///
			 std_post_rprinc_5_ std_post_aint_month_5_year_ act_post_rprinc_5_ ///
			 act_post_aint_month_5_year_ act_interest_forgiven_5_ ///
			 rp_running_princ_bal_6_ ///
			 std_running_princ_bal_6_ act_running_princ_bal_6_ rp_interest_month_6_year_ /// 
			 std_interest_month_6_year_  act_interest_month_6_year_ rp_accum_int_month_6_year_ ///
			 std_accum_int_month_6_year_ act_accum_int_month_6_year_ rp_total_balance_6_ ///
			 std_total_balance_6_ ten_perc_6_year_ repaye_payment_month_6_year_ repaye_int_pt_6_ ///
			 repaye_minus_int_6_ repaye_princ_pt_6_ rp_interest_change_6_ std_payment_6_ ///
			 std_int_pt_6_ std_minus_int_6_ std_princ_pt_6_ std_interest_change_6_ ///
			 actual_payment_6_ actual_int_pt_6_ actual_princ_pt_6_ actual_interest_change_6_ ///
			 pts_not_equal_flag_6_ rp_post_rprinc_6_ rp_post_aint_month_6_year_ ///
			 std_post_rprinc_6_ std_post_aint_month_6_year_ act_post_rprinc_6_ ///
			 act_post_aint_month_6_year_ act_interest_forgiven_6_ ///
			 rp_running_princ_bal_7_ ///
			 std_running_princ_bal_7_ act_running_princ_bal_7_ rp_interest_month_7_year_ /// 
			 std_interest_month_7_year_  act_interest_month_7_year_ rp_accum_int_month_7_year_ ///
			 std_accum_int_month_7_year_ act_accum_int_month_7_year_ rp_total_balance_7_ ///
			 std_total_balance_7_ ten_perc_7_year_ repaye_payment_month_7_year_ repaye_int_pt_7_ ///
			 repaye_minus_int_7_ repaye_princ_pt_7_ rp_interest_change_7_ std_payment_7_ ///
			 std_int_pt_7_ std_minus_int_7_ std_princ_pt_7_ std_interest_change_7_ ///
			 actual_payment_7_ actual_int_pt_7_ actual_princ_pt_7_ actual_interest_change_7_ ///
			 pts_not_equal_flag_7_ rp_post_rprinc_7_ rp_post_aint_month_7_year_ ///
			 std_post_rprinc_7_ std_post_aint_month_7_year_ act_post_rprinc_7_ ///
			 act_post_aint_month_7_year_ act_interest_forgiven_7_ ///
			 rp_running_princ_bal_8_ ///
			 std_running_princ_bal_8_ act_running_princ_bal_8_ rp_interest_month_8_year_ /// 
			 std_interest_month_8_year_  act_interest_month_8_year_ rp_accum_int_month_8_year_ ///
			 std_accum_int_month_8_year_ act_accum_int_month_8_year_ rp_total_balance_8_ ///
			 std_total_balance_8_ ten_perc_8_year_ repaye_payment_month_8_year_ repaye_int_pt_8_ ///
			 repaye_minus_int_8_ repaye_princ_pt_8_ rp_interest_change_8_ std_payment_8_ ///
			 std_int_pt_8_ std_minus_int_8_ std_princ_pt_8_ std_interest_change_8_ ///
			 actual_payment_8_ actual_int_pt_8_ actual_princ_pt_8_ actual_interest_change_8_ ///
			 pts_not_equal_flag_8_ rp_post_rprinc_8_ rp_post_aint_month_8_year_ ///
			 std_post_rprinc_8_ std_post_aint_month_8_year_ act_post_rprinc_8_ ///
			 act_post_aint_month_8_year_ act_interest_forgiven_8_ ///
			 rp_running_princ_bal_9_ ///
			 std_running_princ_bal_9_ act_running_princ_bal_9_ rp_interest_month_9_year_ /// 
			 std_interest_month_9_year_  act_interest_month_9_year_ rp_accum_int_month_9_year_ ///
			 std_accum_int_month_9_year_ act_accum_int_month_9_year_ rp_total_balance_9_ ///
			 std_total_balance_9_ ten_perc_9_year_ repaye_payment_month_9_year_ repaye_int_pt_9_ ///
			 repaye_minus_int_9_ repaye_princ_pt_9_ rp_interest_change_9_ std_payment_9_ ///
			 std_int_pt_9_ std_minus_int_9_ std_princ_pt_9_ std_interest_change_9_ ///
			 actual_payment_9_ actual_int_pt_9_ actual_princ_pt_9_ actual_interest_change_9_ ///
			 pts_not_equal_flag_9_ rp_post_rprinc_9_ rp_post_aint_month_9_year_ ///
			 std_post_rprinc_9_ std_post_aint_month_9_year_ act_post_rprinc_9_ ///
			 act_post_aint_month_9_year_ act_interest_forgiven_9_ ///
			 rp_running_princ_bal_10_ ///
			 std_running_princ_bal_10_ act_running_princ_bal_10_ rp_interest_month_10_year_ /// 
			 std_interest_month_10_year_  act_interest_month_10_year_ rp_accum_int_month_10_year_ ///
			 std_accum_int_month_10_year_ act_accum_int_month_10_year_ rp_total_balance_10_ ///
			 std_total_balance_10_ ten_perc_10_year_ repaye_payment_month_10_year_ repaye_int_pt_10_ ///
			 repaye_minus_int_10_ repaye_princ_pt_10_ rp_interest_change_10_ std_payment_10_ ///
			 std_int_pt_10_ std_minus_int_10_ std_princ_pt_10_ std_interest_change_10_ ///
			 actual_payment_10_ actual_int_pt_10_ actual_princ_pt_10_ actual_interest_change_10_ ///
			 pts_not_equal_flag_10_ rp_post_rprinc_10_ rp_post_aint_month_10_year_ ///
			 std_post_rprinc_10_ std_post_aint_month_10_year_ act_post_rprinc_10_ ///
			 act_post_aint_month_10_year_ act_interest_forgiven_10_ ///
			 rp_running_princ_bal_11_ ///
			 std_running_princ_bal_11_ act_running_princ_bal_11_ rp_interest_month_11_year_ /// 
			 std_interest_month_11_year_  act_interest_month_11_year_ rp_accum_int_month_11_year_ ///
			 std_accum_int_month_11_year_ act_accum_int_month_11_year_ rp_total_balance_11_ ///
			 std_total_balance_11_ ten_perc_11_year_ repaye_payment_month_11_year_ repaye_int_pt_11_ ///
			 repaye_minus_int_11_ repaye_princ_pt_11_ rp_interest_change_11_ std_payment_11_ ///
			 std_int_pt_11_ std_minus_int_11_ std_princ_pt_11_ std_interest_change_11_ ///
			 actual_payment_11_ actual_int_pt_11_ actual_princ_pt_11_ actual_interest_change_11_ ///
			 pts_not_equal_flag_11_ rp_post_rprinc_11_ rp_post_aint_month_11_year_ ///
			 std_post_rprinc_11_ std_post_aint_month_11_year_ act_post_rprinc_11_ ///
			 act_post_aint_month_11_year_ act_interest_forgiven_11_ ///
			 rp_running_princ_bal_12_ ///
			 std_running_princ_bal_12_ act_running_princ_bal_12_ rp_interest_month_12_year_ /// 
			 std_interest_month_12_year_  act_interest_month_12_year_ rp_accum_int_month_12_year_ ///
			 std_accum_int_month_12_year_ act_accum_int_month_12_year_ rp_total_balance_12_ ///
			 std_total_balance_12_ ten_perc_12_year_ repaye_payment_month_12_year_ repaye_int_pt_12_ ///
			 repaye_minus_int_12_ repaye_princ_pt_12_ rp_interest_change_12_ std_payment_12_ ///
			 std_int_pt_12_ std_minus_int_12_ std_princ_pt_12_ std_interest_change_12_ ///
			 actual_payment_12_ actual_int_pt_12_ actual_princ_pt_12_ actual_interest_change_12_ ///
			 pts_not_equal_flag_12_ rp_post_rprinc_12_ rp_post_aint_month_12_year_ ///
			 std_post_rprinc_12_ std_post_aint_month_12_year_ act_post_rprinc_12_ ///
			 act_post_aint_month_12_year_ act_interest_forgiven_12_, i(opciplev) j(year)
		
		*Quick rename of some varaibles to make room for new panel versions
		rename med_earnings med_earnings_orig
		rename standard_payment standard_payment_orig 
		rename rp_running_princ_bal rp_running_princ_bal_orig
		rename std_running_princ_bal std_running_princ_bal_orig
		rename act_running_princ_bal act_running_princ_bal_orig
	
		*Rename all these variables to drop the _year suffix 
		rename (earnings_year_ disc_med_earn_year_ ///
			 rp_running_princ_bal_1_ ///
			 std_running_princ_bal_1_ act_running_princ_bal_1_ rp_interest_month_1_year_ /// 
			 std_interest_month_1_year_  act_interest_month_1_year_ rp_accum_int_month_1_year_ ///
			 std_accum_int_month_1_year_ act_accum_int_month_1_year_ rp_total_balance_1_ ///
			 std_total_balance_1_ ten_perc_1_year_ repaye_payment_month_1_year_ repaye_int_pt_1_ ///
			 repaye_minus_int_1_ repaye_princ_pt_1_ rp_interest_change_1_ std_payment_1_ ///
			 std_int_pt_1_ std_minus_int_1_ std_princ_pt_1_ std_interest_change_1_ ///
			 actual_payment_1_ actual_int_pt_1_ actual_princ_pt_1_ actual_interest_change_1_ ///
			 pts_not_equal_flag_1_ rp_post_rprinc_1_ rp_post_aint_month_1_year_ ///
			 std_post_rprinc_1_ std_post_aint_month_1_year_ act_post_rprinc_1_ ///
			 act_post_aint_month_1_year_ act_interest_forgiven_1_ ///
			 rp_running_princ_bal_2_ ///
			 std_running_princ_bal_2_ act_running_princ_bal_2_ rp_interest_month_2_year_ /// 
			 std_interest_month_2_year_  act_interest_month_2_year_ rp_accum_int_month_2_year_ ///
			 std_accum_int_month_2_year_ act_accum_int_month_2_year_ rp_total_balance_2_ ///
			 std_total_balance_2_ ten_perc_2_year_ repaye_payment_month_2_year_ repaye_int_pt_2_ ///
			 repaye_minus_int_2_ repaye_princ_pt_2_ rp_interest_change_2_ std_payment_2_ ///
			 std_int_pt_2_ std_minus_int_2_ std_princ_pt_2_ std_interest_change_2_ ///
			 actual_payment_2_ actual_int_pt_2_ actual_princ_pt_2_ actual_interest_change_2_ ///
			 pts_not_equal_flag_2_ rp_post_rprinc_2_ rp_post_aint_month_2_year_ ///
			 std_post_rprinc_2_ std_post_aint_month_2_year_ act_post_rprinc_2_ ///
			 act_post_aint_month_2_year_ act_interest_forgiven_2_ ///
			 rp_running_princ_bal_3_ ///
			 std_running_princ_bal_3_ act_running_princ_bal_3_ rp_interest_month_3_year_ /// 
			 std_interest_month_3_year_  act_interest_month_3_year_ rp_accum_int_month_3_year_ ///
			 std_accum_int_month_3_year_ act_accum_int_month_3_year_ rp_total_balance_3_ ///
			 std_total_balance_3_ ten_perc_3_year_ repaye_payment_month_3_year_ repaye_int_pt_3_ ///
			 repaye_minus_int_3_ repaye_princ_pt_3_ rp_interest_change_3_ std_payment_3_ ///
			 std_int_pt_3_ std_minus_int_3_ std_princ_pt_3_ std_interest_change_3_ ///
			 actual_payment_3_ actual_int_pt_3_ actual_princ_pt_3_ actual_interest_change_3_ ///
			 pts_not_equal_flag_3_ rp_post_rprinc_3_ rp_post_aint_month_3_year_ ///
			 std_post_rprinc_3_ std_post_aint_month_3_year_ act_post_rprinc_3_ ///
			 act_post_aint_month_3_year_ act_interest_forgiven_3_ ///
			 rp_running_princ_bal_4_ ///
			 std_running_princ_bal_4_ act_running_princ_bal_4_ rp_interest_month_4_year_ /// 
			 std_interest_month_4_year_  act_interest_month_4_year_ rp_accum_int_month_4_year_ ///
			 std_accum_int_month_4_year_ act_accum_int_month_4_year_ rp_total_balance_4_ ///
			 std_total_balance_4_ ten_perc_4_year_ repaye_payment_month_4_year_ repaye_int_pt_4_ ///
			 repaye_minus_int_4_ repaye_princ_pt_4_ rp_interest_change_4_ std_payment_4_ ///
			 std_int_pt_4_ std_minus_int_4_ std_princ_pt_4_ std_interest_change_4_ ///
			 actual_payment_4_ actual_int_pt_4_ actual_princ_pt_4_ actual_interest_change_4_ ///
			 pts_not_equal_flag_4_ rp_post_rprinc_4_ rp_post_aint_month_4_year_ ///
			 std_post_rprinc_4_ std_post_aint_month_4_year_ act_post_rprinc_4_ ///
			 act_post_aint_month_4_year_ act_interest_forgiven_4_ ///
			 rp_running_princ_bal_5_ ///
			 std_running_princ_bal_5_ act_running_princ_bal_5_ rp_interest_month_5_year_ /// 
			 std_interest_month_5_year_  act_interest_month_5_year_ rp_accum_int_month_5_year_ ///
			 std_accum_int_month_5_year_ act_accum_int_month_5_year_ rp_total_balance_5_ ///
			 std_total_balance_5_ ten_perc_5_year_ repaye_payment_month_5_year_ repaye_int_pt_5_ ///
			 repaye_minus_int_5_ repaye_princ_pt_5_ rp_interest_change_5_ std_payment_5_ ///
			 std_int_pt_5_ std_minus_int_5_ std_princ_pt_5_ std_interest_change_5_ ///
			 actual_payment_5_ actual_int_pt_5_ actual_princ_pt_5_ actual_interest_change_5_ ///
			 pts_not_equal_flag_5_ rp_post_rprinc_5_ rp_post_aint_month_5_year_ ///
			 std_post_rprinc_5_ std_post_aint_month_5_year_ act_post_rprinc_5_ ///
			 act_post_aint_month_5_year_ act_interest_forgiven_5_ ///
			 rp_running_princ_bal_6_ ///
			 std_running_princ_bal_6_ act_running_princ_bal_6_ rp_interest_month_6_year_ /// 
			 std_interest_month_6_year_  act_interest_month_6_year_ rp_accum_int_month_6_year_ ///
			 std_accum_int_month_6_year_ act_accum_int_month_6_year_ rp_total_balance_6_ ///
			 std_total_balance_6_ ten_perc_6_year_ repaye_payment_month_6_year_ repaye_int_pt_6_ ///
			 repaye_minus_int_6_ repaye_princ_pt_6_ rp_interest_change_6_ std_payment_6_ ///
			 std_int_pt_6_ std_minus_int_6_ std_princ_pt_6_ std_interest_change_6_ ///
			 actual_payment_6_ actual_int_pt_6_ actual_princ_pt_6_ actual_interest_change_6_ ///
			 pts_not_equal_flag_6_ rp_post_rprinc_6_ rp_post_aint_month_6_year_ ///
			 std_post_rprinc_6_ std_post_aint_month_6_year_ act_post_rprinc_6_ ///
			 act_post_aint_month_6_year_ act_interest_forgiven_6_ ///
			 rp_running_princ_bal_7_ ///
			 std_running_princ_bal_7_ act_running_princ_bal_7_ rp_interest_month_7_year_ /// 
			 std_interest_month_7_year_  act_interest_month_7_year_ rp_accum_int_month_7_year_ ///
			 std_accum_int_month_7_year_ act_accum_int_month_7_year_ rp_total_balance_7_ ///
			 std_total_balance_7_ ten_perc_7_year_ repaye_payment_month_7_year_ repaye_int_pt_7_ ///
			 repaye_minus_int_7_ repaye_princ_pt_7_ rp_interest_change_7_ std_payment_7_ ///
			 std_int_pt_7_ std_minus_int_7_ std_princ_pt_7_ std_interest_change_7_ ///
			 actual_payment_7_ actual_int_pt_7_ actual_princ_pt_7_ actual_interest_change_7_ ///
			 pts_not_equal_flag_7_ rp_post_rprinc_7_ rp_post_aint_month_7_year_ ///
			 std_post_rprinc_7_ std_post_aint_month_7_year_ act_post_rprinc_7_ ///
			 act_post_aint_month_7_year_ act_interest_forgiven_7_ ///
			 rp_running_princ_bal_8_ ///
			 std_running_princ_bal_8_ act_running_princ_bal_8_ rp_interest_month_8_year_ /// 
			 std_interest_month_8_year_  act_interest_month_8_year_ rp_accum_int_month_8_year_ ///
			 std_accum_int_month_8_year_ act_accum_int_month_8_year_ rp_total_balance_8_ ///
			 std_total_balance_8_ ten_perc_8_year_ repaye_payment_month_8_year_ repaye_int_pt_8_ ///
			 repaye_minus_int_8_ repaye_princ_pt_8_ rp_interest_change_8_ std_payment_8_ ///
			 std_int_pt_8_ std_minus_int_8_ std_princ_pt_8_ std_interest_change_8_ ///
			 actual_payment_8_ actual_int_pt_8_ actual_princ_pt_8_ actual_interest_change_8_ ///
			 pts_not_equal_flag_8_ rp_post_rprinc_8_ rp_post_aint_month_8_year_ ///
			 std_post_rprinc_8_ std_post_aint_month_8_year_ act_post_rprinc_8_ ///
			 act_post_aint_month_8_year_ act_interest_forgiven_8_ ///
			 rp_running_princ_bal_9_ ///
			 std_running_princ_bal_9_ act_running_princ_bal_9_ rp_interest_month_9_year_ /// 
			 std_interest_month_9_year_  act_interest_month_9_year_ rp_accum_int_month_9_year_ ///
			 std_accum_int_month_9_year_ act_accum_int_month_9_year_ rp_total_balance_9_ ///
			 std_total_balance_9_ ten_perc_9_year_ repaye_payment_month_9_year_ repaye_int_pt_9_ ///
			 repaye_minus_int_9_ repaye_princ_pt_9_ rp_interest_change_9_ std_payment_9_ ///
			 std_int_pt_9_ std_minus_int_9_ std_princ_pt_9_ std_interest_change_9_ ///
			 actual_payment_9_ actual_int_pt_9_ actual_princ_pt_9_ actual_interest_change_9_ ///
			 pts_not_equal_flag_9_ rp_post_rprinc_9_ rp_post_aint_month_9_year_ ///
			 std_post_rprinc_9_ std_post_aint_month_9_year_ act_post_rprinc_9_ ///
			 act_post_aint_month_9_year_ act_interest_forgiven_9_ ///
			 rp_running_princ_bal_10_ ///
			 std_running_princ_bal_10_ act_running_princ_bal_10_ rp_interest_month_10_year_ /// 
			 std_interest_month_10_year_  act_interest_month_10_year_ rp_accum_int_month_10_year_ ///
			 std_accum_int_month_10_year_ act_accum_int_month_10_year_ rp_total_balance_10_ ///
			 std_total_balance_10_ ten_perc_10_year_ repaye_payment_month_10_year_ repaye_int_pt_10_ ///
			 repaye_minus_int_10_ repaye_princ_pt_10_ rp_interest_change_10_ std_payment_10_ ///
			 std_int_pt_10_ std_minus_int_10_ std_princ_pt_10_ std_interest_change_10_ ///
			 actual_payment_10_ actual_int_pt_10_ actual_princ_pt_10_ actual_interest_change_10_ ///
			 pts_not_equal_flag_10_ rp_post_rprinc_10_ rp_post_aint_month_10_year_ ///
			 std_post_rprinc_10_ std_post_aint_month_10_year_ act_post_rprinc_10_ ///
			 act_post_aint_month_10_year_ act_interest_forgiven_10_ ///
			 rp_running_princ_bal_11_ ///
			 std_running_princ_bal_11_ act_running_princ_bal_11_ rp_interest_month_11_year_ /// 
			 std_interest_month_11_year_  act_interest_month_11_year_ rp_accum_int_month_11_year_ ///
			 std_accum_int_month_11_year_ act_accum_int_month_11_year_ rp_total_balance_11_ ///
			 std_total_balance_11_ ten_perc_11_year_ repaye_payment_month_11_year_ repaye_int_pt_11_ ///
			 repaye_minus_int_11_ repaye_princ_pt_11_ rp_interest_change_11_ std_payment_11_ ///
			 std_int_pt_11_ std_minus_int_11_ std_princ_pt_11_ std_interest_change_11_ ///
			 actual_payment_11_ actual_int_pt_11_ actual_princ_pt_11_ actual_interest_change_11_ ///
			 pts_not_equal_flag_11_ rp_post_rprinc_11_ rp_post_aint_month_11_year_ ///
			 std_post_rprinc_11_ std_post_aint_month_11_year_ act_post_rprinc_11_ ///
			 act_post_aint_month_11_year_ act_interest_forgiven_11_ ///
			 rp_running_princ_bal_12_ ///
			 std_running_princ_bal_12_ act_running_princ_bal_12_ rp_interest_month_12_year_ /// 
			 std_interest_month_12_year_  act_interest_month_12_year_ rp_accum_int_month_12_year_ ///
			 std_accum_int_month_12_year_ act_accum_int_month_12_year_ rp_total_balance_12_ ///
			 std_total_balance_12_ ten_perc_12_year_ repaye_payment_month_12_year_ repaye_int_pt_12_ ///
			 repaye_minus_int_12_ repaye_princ_pt_12_ rp_interest_change_12_ std_payment_12_ ///
			 std_int_pt_12_ std_minus_int_12_ std_princ_pt_12_ std_interest_change_12_ ///
			 actual_payment_12_ actual_int_pt_12_ actual_princ_pt_12_ actual_interest_change_12_ ///
			 pts_not_equal_flag_12_ rp_post_rprinc_12_ rp_post_aint_month_12_year_ ///
			 std_post_rprinc_12_ std_post_aint_month_12_year_ act_post_rprinc_12_ ///
			 act_post_aint_month_12_year_ act_interest_forgiven_12_) ///
			(earnings disc_med_earn ///
			 rp_running_princ_bal_1 ///
			 std_running_princ_bal_1 act_running_princ_bal_1 rp_interest_month_1 /// 
			 std_interest_month_1  act_interest_month_1 rp_accum_int_month_1 ///
			 std_accum_int_month_1 act_accum_int_month_1 rp_total_balance_1 ///
			 std_total_balance_1 ten_perc_1 repaye_payment_month_1 repaye_int_pt_1 ///
			 repaye_minus_int_1 repaye_princ_pt_1 rp_interest_change_1 std_payment_1 ///
			 std_int_pt_1 std_minus_int_1 std_princ_pt_1 std_interest_change_1 ///
			 actual_payment_1 actual_int_pt_1 actual_princ_pt_1 actual_interest_change_1 ///
			 pts_not_equal_flag_1 rp_post_rprinc_1 rp_post_aint_month_1 ///
			 std_post_rprinc_1 std_post_aint_month_1 act_post_rprinc_1 ///
			 act_post_aint_month_1 act_interest_forgiven_1 ///
			 rp_running_princ_bal_2 ///
			 std_running_princ_bal_2 act_running_princ_bal_2 rp_interest_month_2 /// 
			 std_interest_month_2  act_interest_month_2 rp_accum_int_month_2 ///
			 std_accum_int_month_2 act_accum_int_month_2 rp_total_balance_2 ///
			 std_total_balance_2 ten_perc_2 repaye_payment_month_2 repaye_int_pt_2 ///
			 repaye_minus_int_2 repaye_princ_pt_2 rp_interest_change_2 std_payment_2 ///
			 std_int_pt_2 std_minus_int_2 std_princ_pt_2 std_interest_change_2 ///
			 actual_payment_2 actual_int_pt_2 actual_princ_pt_2 actual_interest_change_2 ///
			 pts_not_equal_flag_2 rp_post_rprinc_2 rp_post_aint_month_2 ///
			 std_post_rprinc_2 std_post_aint_month_2 act_post_rprinc_2 ///
			 act_post_aint_month_2 act_interest_forgiven_2 ///
			 rp_running_princ_bal_3 ///
			 std_running_princ_bal_3 act_running_princ_bal_3 rp_interest_month_3 /// 
			 std_interest_month_3  act_interest_month_3 rp_accum_int_month_3 ///
			 std_accum_int_month_3 act_accum_int_month_3 rp_total_balance_3 ///
			 std_total_balance_3 ten_perc_3 repaye_payment_month_3 repaye_int_pt_3 ///
			 repaye_minus_int_3 repaye_princ_pt_3 rp_interest_change_3 std_payment_3 ///
			 std_int_pt_3 std_minus_int_3 std_princ_pt_3 std_interest_change_3 ///
			 actual_payment_3 actual_int_pt_3 actual_princ_pt_3 actual_interest_change_3 ///
			 pts_not_equal_flag_3 rp_post_rprinc_3 rp_post_aint_month_3 ///
			 std_post_rprinc_3 std_post_aint_month_3 act_post_rprinc_3 ///
			 act_post_aint_month_3 act_interest_forgiven_3 ///
			 rp_running_princ_bal_4 ///
			 std_running_princ_bal_4 act_running_princ_bal_4 rp_interest_month_4 /// 
			 std_interest_month_4  act_interest_month_4 rp_accum_int_month_4 ///
			 std_accum_int_month_4 act_accum_int_month_4 rp_total_balance_4 ///
			 std_total_balance_4 ten_perc_4 repaye_payment_month_4 repaye_int_pt_4 ///
			 repaye_minus_int_4 repaye_princ_pt_4 rp_interest_change_4 std_payment_4 ///
			 std_int_pt_4 std_minus_int_4 std_princ_pt_4 std_interest_change_4 ///
			 actual_payment_4 actual_int_pt_4 actual_princ_pt_4 actual_interest_change_4 ///
			 pts_not_equal_flag_4 rp_post_rprinc_4 rp_post_aint_month_4 ///
			 std_post_rprinc_4 std_post_aint_month_4 act_post_rprinc_4 ///
			 act_post_aint_month_4 act_interest_forgiven_4 ///
			 rp_running_princ_bal_5 ///
			 std_running_princ_bal_5 act_running_princ_bal_5 rp_interest_month_5 /// 
			 std_interest_month_5  act_interest_month_5 rp_accum_int_month_5 ///
			 std_accum_int_month_5 act_accum_int_month_5 rp_total_balance_5 ///
			 std_total_balance_5 ten_perc_5 repaye_payment_month_5 repaye_int_pt_5 ///
			 repaye_minus_int_5 repaye_princ_pt_5 rp_interest_change_5 std_payment_5 ///
			 std_int_pt_5 std_minus_int_5 std_princ_pt_5 std_interest_change_5 ///
			 actual_payment_5 actual_int_pt_5 actual_princ_pt_5 actual_interest_change_5 ///
			 pts_not_equal_flag_5 rp_post_rprinc_5 rp_post_aint_month_5 ///
			 std_post_rprinc_5 std_post_aint_month_5 act_post_rprinc_5 ///
			 act_post_aint_month_5 act_interest_forgiven_5 ///
			 rp_running_princ_bal_6 ///
			 std_running_princ_bal_6 act_running_princ_bal_6 rp_interest_month_6 /// 
			 std_interest_month_6  act_interest_month_6 rp_accum_int_month_6 ///
			 std_accum_int_month_6 act_accum_int_month_6 rp_total_balance_6 ///
			 std_total_balance_6 ten_perc_6 repaye_payment_month_6 repaye_int_pt_6 ///
			 repaye_minus_int_6 repaye_princ_pt_6 rp_interest_change_6 std_payment_6 ///
			 std_int_pt_6 std_minus_int_6 std_princ_pt_6 std_interest_change_6 ///
			 actual_payment_6 actual_int_pt_6 actual_princ_pt_6 actual_interest_change_6 ///
			 pts_not_equal_flag_6 rp_post_rprinc_6 rp_post_aint_month_6 ///
			 std_post_rprinc_6 std_post_aint_month_6 act_post_rprinc_6 ///
			 act_post_aint_month_6 act_interest_forgiven_6 ///
			 rp_running_princ_bal_7 ///
			 std_running_princ_bal_7 act_running_princ_bal_7 rp_interest_month_7 /// 
			 std_interest_month_7  act_interest_month_7 rp_accum_int_month_7 ///
			 std_accum_int_month_7 act_accum_int_month_7 rp_total_balance_7 ///
			 std_total_balance_7 ten_perc_7 repaye_payment_month_7 repaye_int_pt_7 ///
			 repaye_minus_int_7 repaye_princ_pt_7 rp_interest_change_7 std_payment_7 ///
			 std_int_pt_7 std_minus_int_7 std_princ_pt_7 std_interest_change_7 ///
			 actual_payment_7 actual_int_pt_7 actual_princ_pt_7 actual_interest_change_7 ///
			 pts_not_equal_flag_7 rp_post_rprinc_7 rp_post_aint_month_7 ///
			 std_post_rprinc_7 std_post_aint_month_7 act_post_rprinc_7 ///
			 act_post_aint_month_7 act_interest_forgiven_7 ///
			 rp_running_princ_bal_8 ///
			 std_running_princ_bal_8 act_running_princ_bal_8 rp_interest_month_8 /// 
			 std_interest_month_8  act_interest_month_8 rp_accum_int_month_8 ///
			 std_accum_int_month_8 act_accum_int_month_8 rp_total_balance_8 ///
			 std_total_balance_8 ten_perc_8 repaye_payment_month_8 repaye_int_pt_8 ///
			 repaye_minus_int_8 repaye_princ_pt_8 rp_interest_change_8 std_payment_8 ///
			 std_int_pt_8 std_minus_int_8 std_princ_pt_8 std_interest_change_8 ///
			 actual_payment_8 actual_int_pt_8 actual_princ_pt_8 actual_interest_change_8 ///
			 pts_not_equal_flag_8 rp_post_rprinc_8 rp_post_aint_month_8 ///
			 std_post_rprinc_8 std_post_aint_month_8 act_post_rprinc_8 ///
			 act_post_aint_month_8 act_interest_forgiven_8 ///
			 rp_running_princ_bal_9 ///
			 std_running_princ_bal_9 act_running_princ_bal_9 rp_interest_month_9 /// 
			 std_interest_month_9  act_interest_month_9 rp_accum_int_month_9 ///
			 std_accum_int_month_9 act_accum_int_month_9 rp_total_balance_9 ///
			 std_total_balance_9 ten_perc_9 repaye_payment_month_9 repaye_int_pt_9 ///
			 repaye_minus_int_9 repaye_princ_pt_9 rp_interest_change_9 std_payment_9 ///
			 std_int_pt_9 std_minus_int_9 std_princ_pt_9 std_interest_change_9 ///
			 actual_payment_9 actual_int_pt_9 actual_princ_pt_9 actual_interest_change_9 ///
			 pts_not_equal_flag_9 rp_post_rprinc_9 rp_post_aint_month_9 ///
			 std_post_rprinc_9 std_post_aint_month_9 act_post_rprinc_9 ///
			 act_post_aint_month_9 act_interest_forgiven_9 ///
			 rp_running_princ_bal_10 ///
			 std_running_princ_bal_10 act_running_princ_bal_10 rp_interest_month_10 /// 
			 std_interest_month_10  act_interest_month_10 rp_accum_int_month_10 ///
			 std_accum_int_month_10 act_accum_int_month_10 rp_total_balance_10 ///
			 std_total_balance_10 ten_perc_10 repaye_payment_month_10 repaye_int_pt_10 ///
			 repaye_minus_int_10 repaye_princ_pt_10 rp_interest_change_10 std_payment_10 ///
			 std_int_pt_10 std_minus_int_10 std_princ_pt_10 std_interest_change_10 ///
			 actual_payment_10 actual_int_pt_10 actual_princ_pt_10 actual_interest_change_10 ///
			 pts_not_equal_flag_10 rp_post_rprinc_10 rp_post_aint_month_10 ///
			 std_post_rprinc_10 std_post_aint_month_10 act_post_rprinc_10 ///
			 act_post_aint_month_10 act_interest_forgiven_10 ///
			 rp_running_princ_bal_11 ///
			 std_running_princ_bal_11 act_running_princ_bal_11 rp_interest_month_11 /// 
			 std_interest_month_11  act_interest_month_11 rp_accum_int_month_11 ///
			 std_accum_int_month_11 act_accum_int_month_11 rp_total_balance_11 ///
			 std_total_balance_11 ten_perc_11 repaye_payment_month_11 repaye_int_pt_11 ///
			 repaye_minus_int_11 repaye_princ_pt_11 rp_interest_change_11 std_payment_11 ///
			 std_int_pt_11 std_minus_int_11 std_princ_pt_11 std_interest_change_11 ///
			 actual_payment_11 actual_int_pt_11 actual_princ_pt_11 actual_interest_change_11 ///
			 pts_not_equal_flag_11 rp_post_rprinc_11 rp_post_aint_month_11 ///
			 std_post_rprinc_11 std_post_aint_month_11 act_post_rprinc_11 ///
			 act_post_aint_month_11 act_interest_forgiven_11 ///
			 rp_running_princ_bal_12 ///
			 std_running_princ_bal_12 act_running_princ_bal_12 rp_interest_month_12 /// 
			 std_interest_month_12  act_interest_month_12 rp_accum_int_month_12 ///
			 std_accum_int_month_12 act_accum_int_month_12 rp_total_balance_12 ///
			 std_total_balance_12 ten_perc_12 repaye_payment_month_12 repaye_int_pt_12 ///
			 repaye_minus_int_12 repaye_princ_pt_12 rp_interest_change_12 std_payment_12 ///
			 std_int_pt_12 std_minus_int_12 std_princ_pt_12 std_interest_change_12 ///
			 actual_payment_12 actual_int_pt_12 actual_princ_pt_12 actual_interest_change_12 ///
			 pts_not_equal_flag_12 rp_post_rprinc_12 rp_post_aint_month_12 ///
			 std_post_rprinc_12 std_post_aint_month_12 act_post_rprinc_12 ///
			 act_post_aint_month_12 act_interest_forgiven_12)
	
		*Reshape 
		reshape long rp_running_princ_bal_ ///
			 std_running_princ_bal_ act_running_princ_bal_ rp_interest_month_ /// 
			 std_interest_month_  act_interest_month_ rp_accum_int_month_ ///
			 std_accum_int_month_ act_accum_int_month_ rp_total_balance_ ///
			 std_total_balance_ ten_perc_ repaye_payment_month_ repaye_int_pt_ ///
			 repaye_minus_int_ repaye_princ_pt_ rp_interest_change_ std_payment_ ///
			 std_int_pt_ std_minus_int_ std_princ_pt_ std_interest_change_ ///
			 actual_payment_ actual_int_pt_ actual_princ_pt_ actual_interest_change_ ///
			 pts_not_equal_flag_ rp_post_rprinc_ rp_post_aint_month_ ///
			 std_post_rprinc_ std_post_aint_month_ act_post_rprinc_ ///
			 act_post_aint_month_ act_interest_forgiven_, i(opciplev year) j(month) 
	
		*Rename variabes to drop _month suffix
		rename (rp_running_princ_bal_ ///
			 std_running_princ_bal_ act_running_princ_bal_ rp_interest_month_ /// 
			 std_interest_month_  act_interest_month_ rp_accum_int_month_ ///
			 std_accum_int_month_ act_accum_int_month_ rp_total_balance_ ///
			 std_total_balance_ ten_perc_ repaye_payment_month_ repaye_int_pt_ ///
			 repaye_minus_int_ repaye_princ_pt_ rp_interest_change_ std_payment_ ///
			 std_int_pt_ std_minus_int_ std_princ_pt_ std_interest_change_ ///
			 actual_payment_ actual_int_pt_ actual_princ_pt_ actual_interest_change_ ///
			 pts_not_equal_flag_ rp_post_rprinc_ rp_post_aint_month_ ///
			 std_post_rprinc_ std_post_aint_month_ act_post_rprinc_ ///
			 act_post_aint_month_ act_interest_forgiven_)  ///
			(rp_running_princ_bal ///
			 std_running_princ_bal act_running_princ_bal rp_interest /// 
			 std_interest  act_interest rp_accum_int ///
			 std_accum_int act_accum_int rp_total_balance ///
			 std_total_balance ten_perc repaye_payment repaye_int_pt ///
			 repaye_minus_int repaye_princ_pt rp_interest_change std_payment ///
			 std_int_pt std_minus_int std_princ_pt std_interest_change ///
			 actual_payment actual_int_pt actual_princ_pt actual_interest_change ///
			 pts_not_equal_flag rp_post_rprinc rp_post_aint ///
			 std_post_rprinc std_post_aint act_post_rprinc ///
			 act_post_aint act_interest_forgiven)
		
		*Save this for the grad data only
		saveold "${ge_data}loan_dynamics_calcs_long_grad.dta", replace 
		
			*Run the same analysis for the nongrad programs
			do "${ge_data}CAP_ge_repayment_estimator_replication_code_ugrad.do"
	
		
		
		
		*Start with a basis of the grad data
		use "${ge_data}loan_dynamics_calcs_long_grad.dta", clear 
		
		*Append the nongrad file to our grad file
		append using "${ge_data}loan_dynamics_calcs_long_nongrad.dta"
		
		
		saveold "${ge_data}loan_dynamics_calcs_long_all.dta", replace 
		
		*************
		* After Running the Original Calculations, commenting can stop here
		*************/
		use "${ge_data}loan_dynamics_calcs_long_all.dta", clear 
		
		destring opciplev, replace 
		
		format opciplev %40.0f
		
		***Now Set Up Panel 
		
		*Set true year and months, in terms of true payment year (starting with 2013)
		gen real_year = 2013 if year==1
			replace real_year = (year-1)+2013
			
		*Set date in machine readable form 
		gen modate = ym(real_year, month)
		
		*Now make it human readable
		gen date_fixed = modate
		format %tm  date_fixed 
		
		*Drop the real year variable
		drop real_year 
		
		*Destring ID because xtset requires it
		destring opciplev, replace 
		
		*Panel set the data
		xtset opciplev modate 
		
		*Create a month count across all years
		bys opciplev: gen month_count = _n 
		
		*Calculate the years in which students payoff
		by opciplev (month_count), sort: gen rp_payoff_year = ///
				sum(rp_post_rprinc==0)==1 & sum(rp_post_rprinc[_n-1]==0)==0 
		by opciplev (month_count), sort: gen std_payoff_year = ///
				sum(std_post_rprinc==0)==1 & sum(std_post_rprinc[_n-1]==0)==0 
		by opciplev (month_count), sort: gen act_payoff_year = ///
				sum(act_post_rprinc==0)==1 & sum(act_post_rprinc[_n-1]==0)==0 
		
		*Create an indicator for if the school ever pays off 
		egen rp_payoff_year_sum = total(rp_payoff_year), by(opciplev) 
		egen std_payoff_year_sum = total(std_payoff_year), by(opciplev) 
		egen act_payoff_year_sum = total(act_payoff_year), by(opciplev) 
		
		*Create a OPCIPLEV tag 
		egen prog_tag = tag(opciplev) 
		
		*Calculate the total of interest payments, principal payments, & overall payments
		egen repaye_total_interest_paid = total(repaye_int_pt), by(opciplev)
		egen std_total_interest_paid = total(std_int_pt), by(opciplev)
		egen actual_total_interest_paid = total(actual_int_pt), by(opciplev)
			
		*Generate total principal paid under standard, REPAYE, & actual
		egen repaye_total_principal_paid = total(repaye_princ_pt), by(opciplev)
		egen std_total_principal_paid = total(std_princ_pt), by(opciplev)
		egen actual_total_principal_paid = total(actual_princ_pt), by(opciplev)
		
		*Generate total paid under standard, REPAYE, & actual 
		egen repaye_total_paid = total(repaye_payment), by(opciplev)
		egen std_total_paid = total(std_payment), by(opciplev)
		egen actual_total_paid = total(actual_payment), by(opciplev)
		
		gen rp_payoff_month = month_count if rp_payoff_year
		gen std_payoff_month = month_count if std_payoff_year
		gen act_payoff_month = month_count if act_payoff_year
			
		***Do some final calculations with discounting
		
		/*Set two different interest rates as a bounding exercise
		
			Using same interest rates from GAO interest rate report:
				http://www.gao.gov/assets/670/660548.pdf
				
		*/
		local discount_rate_fav = .028
		local discount_rate_unfav = .05
		
			*Discount the actual payment, and its parts under favorable DR
			gen pdv_act_payment_fav = actual_payment/((1+(`discount_rate_fav'/12))^month_count)
			gen pdv_act_int_pay_fav = actual_int_pt/((1+(`discount_rate_fav'/12))^month_count)
			gen pdv_act_princ_pay_fav = actual_princ_pt/((1+(`discount_rate_fav '/12))^month_count)
			
			*Discount the actual payment, and its parts under unfavorable DR
			gen pdv_act_payment_unfav = actual_payment/((1+(`discount_rate_unfav'/12))^month_count)
			gen pdv_act_int_pay_unfav = actual_int_pt/((1+(`discount_rate_unfav'/12))^month_count)
			gen pdv_act_princ_pay_unfav = actual_princ_pt/((1+(`discount_rate_unfav '/12))^month_count)
			
			*Discount the standard payment, and its parts under favorable DR
			gen pdv_std_payment_fav = std_payment/((1+(`discount_rate_fav'/12))^month_count)
			gen pdv_std_int_pay_fav = std_int_pt/((1+(`discount_rate_fav'/12))^month_count)
			gen pdv_std_princ_pay_fav = std_princ_pt/((1+(`discount_rate_fav '/12))^month_count)
			
			*Discount the standard payment, and its parts under unfavorable DR
			gen pdv_std_payment_unfav = std_payment/((1+(`discount_rate_unfav'/12))^month_count)
			gen pdv_std_int_pay_unfav = std_int_pt/((1+(`discount_rate_unfav'/12))^month_count)
			gen pdv_std_princ_pay_unfav = std_princ_pt/((1+(`discount_rate_unfav '/12))^month_count)
			
			*Figure out discounted value of forgiven interest in each month
			gen pdv_int_forg_fav = act_interest_forgiven/((1+(`discount_rate_fav '/12))^month_count)
			gen pdv_int_forg_unfav = act_interest_forgiven/((1+(`discount_rate_unfav '/12))^month_count)
		
		*Sum up all of the discounted payment amounts under standard & actual repayment schemes		
		egen total_payment_act_fav = total(pdv_act_payment_fav), by(opciplev) 
		egen total_payment_std_fav = total(pdv_std_payment_fav), by(opciplev) 
		egen total_payment_act_unfav = total(pdv_act_payment_unfav), by(opciplev) 
		egen total_payment_std_unfav = total(pdv_std_payment_unfav), by(opciplev) 
		
		*Calculate difference between standard & actual payments (favorable)
		gen fav_dif = total_payment_act_fav-total_payment_std_fav
		
		*Calculate difference between standard & actual payments (unfavorable)
		gen unfav_dif = total_payment_act_unfav-total_payment_std_unfav
			
		*Calculate difference between discounted total paid & original balance (favorable)
		gen fav_princ_dif = total_payment_act_fav-principal_balance
		
		*Calculate difference between discounted total paid & original balance (unfavorable)
		gen unfav_princ_dif = total_payment_act_unfav-principal_balance
		
		*Traditional forgiveness measure = remaining principal + remaining interest 
		gen act_total_int_princ_left = act_running_princ_bal_orig+act_accum_excess_interest
		
			*Calculate discounted versions of traditional forgiveness amount 
				egen max_year = max(year), by(opciplev)
			gen act_total_int_princ_fav = act_total_int_princ_left/((1+(`discount_rate_fav '))^max_year)
			gen act_total_int_princ_unfav = act_total_int_princ_left/((1+(`discount_rate_fav '))^max_year)
		
		*Calculate total interest forgiven on a monthly basis
		egen tot_monthly_int_forgiven = total(act_interest_forgiven), by(opciplev) 
		
			*And discounted versions of same
			egen tot_monthly_int_forg_fav = total(pdv_int_forg_fav), by(opciplev) 
			egen tot_monthly_int_forg_unfav = total(pdv_int_forg_unfav), by(opciplev) 
			
		*Traditional forgiveness measure plus forgiven interest
		gen total_trad_forgiven = act_total_int_princ_left + tot_monthly_int_forgiven
				
		*Calculate Subsidy Cost for REPAYE and Standard plans 
		gen tot_act_repaid_minus_princ_fav = principal_balance-total_payment_act_fav
		gen tot_std_repaid_minus_princ_fav = principal_balance-total_payment_std_fav
		
		gen tot_act_repaid_minus_princ_unfav = principal_balance-total_payment_act_unfav
		gen tot_std_repaid_minus_princ_unfav = principal_balance-total_payment_std_unfav

		************ 
		* Make Tables & Graphs 
		************
		
		*Recode pass_zone_fail for graph making
		replace pass_zone_fail = strproper(pass_zone_fail)
			replace pass_zone_fail = "Failing" if pass_zone_fail=="Fail" 
			replace pass_zone_fail = "Passing" if pass_zone_fail=="Pass" 
			replace pass_zone_fail = "In Zone" if pass_zone_fail=="Zone" 
					
		destring level_code, replace 
		label values level_code level_code 
		
		
		*Create an indicator for non-passing programs, so we can calculate the costs just for these programs
		gen non_pass_prog = pass_zone_fail!="Passing" & !missing(pass_zone_fail)
		
		*Now create a tag for these two groups
		egen non_pass_tag = tag(non_pass_prog) 
	
		***** Tables *****
	
		*Table 1: 
		tabstat prog_tag part_fin_hard if prog_tag, stat(sum) by(pass_zone_fail) save 
		tabstatmat tab1a, nototal
	
		putexcel set "${ge_data}artready_figures_ge_idr_3.xlsx", sheet("Table 1") modify
		
		putexcel B3 = ("Table 1") 
		putexcel B4 = ("Students with typical earnings and debt at all failing & zone programs qualify for a partial financial hardship") 
		putexcel B5 = ("Number of programs and students at programs with partial financial hardship, by program status")
		putexcel B6 = ("Panel A") 
		putexcel B7 = ("Program Status") 
		putexcel B8 = ("Failing")
		putexcel B9 = ("In Zone") 
		putexcel B10 = ("Passing") 
		putexcel C7 = ("Number of Programs") 
		putexcel D7 = ("Number of Programs with Partial Financial Hardship") 
		
		putexcel C8 = matrix(tab1a) 
		
		tabstat prog_tag part_fin_hard if prog_tag, stat(sum) by(pass_zone_fail) save 
		tabstatmat tab1b, nototal
		
		putexcel B11 = ("Panel B")
	
		tabstat stu_count if prog_tag, stat(sum) by(pass_zone_fail) save
		tabstatmat tab2a, nototal 
			
		tabstat stu_count if prog_tag & part_fin_hard, stat(sum) by(pass_zone_fail) save	
		tabstatmat tab2b, nototal 
		
		putexcel C13 = matrix(tab2a) 
		
		putexcel B12 = ("Program Status") 
		putexcel B13 = ("Failing")
		putexcel B14 = ("In Zone") 
		putexcel B15 = ("Passing") 
		putexcel C12 = ("Number of Students") 
		putexcel D12 = ("Number of Students at Programs with Partial Financial Hardship") 
		
		putexcel D13 = matrix(tab2b) 
		
		putexcel B16 = ("Source: Authors' calculations using the gainful employment data for the 2015 debt measure year and a poverty line calculated using the 2014 Health and Human Services poverty guidelines.")
		putexcel B18 = ("Note: Typical earnings is defined as the higher of a school's mean or median earnings, whle typical debt is the median debt for the school. A program is considered to have a partial financial hardship if a student with typical earnings and debt from that program would qualify for a partial financial hardship.")
		
		*Table 2:
		gen control = . 
			replace control = 1 if type_control=="PUBLIC 2 TO 3 YEARS" | ///
								type_control=="PUBLIC 4 YEARS OR MORE" | ///
								type_control=="PUBLIC LESS THAN 2 YEARS" 
			replace control = 2 if type_control=="PRIVATE, NOT-FOR-PROFIT 2 TO 3 YEARS" | ///
								type_control=="PRIVATE, NOT-FOR-PROFIT 4 YEARS OR MORE" | ///
								type_control=="PRIVATE, NOT-FOR-PROFIT LESS THAN 2 YEARS" 
			replace control = 3 if type_control=="PROPRIETARY 2 TO 3 YEARS" | ///
								type_control=="PROPRIETARY 4 YEARS OR MORE" | ///
								type_control=="PROPRIETARY LESS THAN 2 YEARS" 
			
		label define control 1 "Public" 2 "Private, Non-Profit" 3 "Private, For-Profit" 
		label values control control 
		
		*Calculate how much more a typical student would need to earn to avoid a partial financial hardship
			*This amount equals the difference between discretionary median earnings & 10 times standard payment
		gen dist_from_no_pfh = (standard_payment*10*12)-disc_med_earn if month==1 & year==1 
		
			replace dist_from_no_pfh = 0 if dist_from_no_pfh<0 
			
		gen dist_more_than_10 = dist_from_no_pfh>10000 & !missing(dist_from_no_pfh)
		gen dist_more_than_20 = dist_from_no_pfh>20000 & !missing(dist_from_no_pfh)
		gen dist_more_than_30 = dist_from_no_pfh>30000 & !missing(dist_from_no_pfh)
	
		putexcel set "${ge_data}artready_figures_ge_idr_3.xlsx", sheet("Table 2") modify
		
		putexcel B3 = ("Table 2")
		putexcel B4 = ("Students with typical earnings & debt at many programs would need to earn significantly more to avoid qualifying for IDR ")
		putexcel B5 = ("The earnings boost necessary to lift students out of a partial financial hardship, by sector")
		
		putexcel B6 = ("Panel A: Program-weighted results")
		putexcel C7 = ("Number of Non-Passing Programs with Partial Financial Hardship") 
		putexcel D7 = ("Number of Programs that would need at least this amount of money to avoid a partial financial hardship") 
		
		putexcel D8 = (">$10,000") 
		putexcel E8 = (">$20,000")
		putexcel F8 = (">$30,000") 
		
		tabstat part_fin_hard dist_more_than_10 dist_more_than_20 dist_more_than_30 if month==1 & year==1 & non_pass_prog, stat(sum) by(control) save 
		tabstatmat tab3a, nototal
		
		putexcel C9 = matrix(tab3a) 
		
		putexcel B9 = ("Public")
		putexcel B10 = ("Private Nonprofit")
		putexcel B11 = ("Private For-Profit") 
		
		putexcel B12 = ("Panel B: Student-weighted results") 
		
		tabstat stu_count if part_fin_hard & month==1 & year==1 & non_pass_prog, stat(sum) by(control) save 
		tabstatmat tab3b, nototal
		
		putexcel C15 = matrix(tab3b)
		
		tabstat stu_count if dist_more_than_10 & month==1 & year==1 & non_pass_prog, stat(sum) by(control) save 
		tabstatmat tab3c, nototal
		
		putexcel D15 = matrix(tab3c)
		
		tabstat stu_count if dist_more_than_20 & month==1 & year==1 & non_pass_prog, stat(sum) by(control) save 
		tabstatmat tab3d, nototal 
		
		putexcel E15 = matrix(tab3d)
		
		tabstat stu_count if dist_more_than_30 & month==1 & year==1 & non_pass_prog, stat(sum) by(control) save 
		tabstatmat tab3e, nototal
		
		putexcel F16 = matrix(tab3e)
		
		putexcel B15 = ("Public") 
		putexcel B16 = ("Nonprofit") 
		putexcel B17 = ("For-profit") 
		
		putexcel C13 = ("Number of Students at Non-Passing Programs with Partial Financial Hardship") 
		putexcel D13 = ("Number of Students at Programs that would need at least this amount of money to avoid a partial financial hardship") 
		putexcel D14 = (">$10,000") 
		putexcel E14 = (">$20,000") 
		putexcel F14 = (">$30,000") 
		
		putexcel B15 = ("Public") 
		putexcel B16 = ("Nonprofit") 
		putexcel B17 = ("For-profit") 
				
		
		putexcel B18 = ("Source: Authors' calculations using the gainful employment data for the 2015 debt measure year and a poverty line calculated using the 2014 Health and Human Services poverty guidelines.")
		putexcel B20 = ("Note: Typical earnings is defined  the higher of a school's mean or median earnings, whle typical debt is the median debt for the school. A program is considered to have a partial financial hardship if a student with typical earnings and debt from that program would have a lower payment through IDR than on the standard 10-year plan.") 
		
		
		
		tabstatmat tab3a, nototal
		
		
		*Restrict rest of analysis to only schools with principal balance greater than 0 
		*drop if principal_balance==0 | missing(principal_balance) 
		set scheme burd
		set scheme s2color
		
		*Principal Paydown, Undergrad & Grad
			*Undergrad
					preserve 
					drop if inlist(level_code, 5, 6, 7, 8) 
					
			binscatter act_post_rprinc modate [aw=stu_count], ///
				by(pass_zone_fail) linetype(connect) ///
				xlabel(636 "Repayment Begins" 695 "Year 5" 755 "Year 10" 815 "Year 15" 875 "End of Year 20") ///
				medians xtitle("Year in Repayment") ytitle("Remaining Principal in $")  ///
				legend(label(1 "Failing Program") label(2 "Zone Program") label(3 "Passing Program")) ///
				legend(ring(1) position(7) bmargin(small)) title("Undergraduate Programs") ///
				savedata("${ge_data}principal_paydown_by_program_medians_nongrad") replace ///
				savegraph("${ge_data}principal_paydown_by_program_medians_nongrad.gph") ///
				xline(755, lcolor(gray)) xline(875, lcolor(gray))
			
					restore 
		
			*Grad
					preserve 
					drop if inlist(level_code, 1, 2, 3, 4) 
				
			binscatter act_post_rprinc modate [aw=stu_count], ///
				by(pass_zone_fail) linetype(connect) ///
				medians xtitle("Year in Repayment") ytitle("Remaining Principal in $") ///
				xlabel(636 "Repayment Begins" 695 "Year 5" 755 "Year 10" 815 "Year 15" 875 "Year 20" 935 "End of Year 25")   ///
				legend(label(1 "Failing Program") label(2 "Zone Program") label(3 "Passing Program")) ///
				legend(ring(1) position(7) bmargin(small)) title("Graduate Programs") ///
				savedata("${ge_data}principal_paydown_by_program_medians_grad") replace ///
				savegraph("${ge_data}principal_paydown_by_program_medians_grad.gph") ///
				xline(755, lcolor(gray)) xline(875, lcolor(gray))
						
			grc1leg "${ge_data}principal_paydown_by_program_medians_nongrad.gph" ///
				"${ge_data}principal_paydown_by_program_medians_grad.gph", col(1) 
				
			graph export "${ge_data}principal_paydown_by_program_medians_comb.png", replace 
				
					restore
					
			*Add Plot to Spreadsheet
			putexcel set "${ge_data}artready_figures_ge_idr_3.xlsx", sheet("Figure 1") modify
			putexcel B5 = picture("${ge_data}principal_paydown_by_program_medians_comb.png")
		
			putexcel B2 = ("Figure 1") 
			putexcel B2, bold
			
			putexcel B3 = ("Passing undergraduate programs start from a lower loan balance, pay off completely on average")
			putexcel B4 = ("Median principal balance remaining for typical students at GE programs, by program status and level, throughout repayment") 
			
			putexcel B31 = ("Note: Sample includes all undergraduate programs subject to gainful employment regulation with a non-zero starting principal balance. Assumes income growth of 5% per year, and increase in the federal poverty level of 2% per year. Though we calculate the remaining prinicipal balance for each program at the end of each month, this graph displays the median principal balance at less-frequent intervals for ease of visualization. Each point on the graph is then a scatter plot of the point in the life of the loan and the corresponding median principal balance at that point.") 
			
			
			*Add Plot Values to Spreadsheet 
			*Undergrad 
			preserve 
			
			import delimited "${ge_data}principal_paydown_by_program_medians_nongrad.csv", clear
			
			mkmat modate_by1 act_post_rprinc_by1 act_post_rprinc_by2 act_post_rprinc_by3, matrix("Undergrad")
			
			mat colnames Undergrad = "Machine Readable Date" "Failing Program Value" "Zone Program Value" "Passing Program Value"
			
				putexcel set "${ge_data}artready_figures_ge_idr_3.xlsx", sheet("Figure 1") modify
				
				putexcel N6 = matrix(Undergrad), names 
				
			restore 
				
			*Grad
			preserve 
			
			import delimited "${ge_data}principal_paydown_by_program_medians_grad.csv", clear
			
			mkmat modate_by1 act_post_rprinc_by1 act_post_rprinc_by2 act_post_rprinc_by3, matrix("Grad")
			
			mat colnames Grad = "Machine Readable Date" "Failing Program Value" "Zone Program Value" "Passing Program Value"
			
				putexcel set "${ge_data}artready_figures_ge_idr_3.xlsx", sheet("Figure 1") modify
				
				putexcel N30 = matrix(Grad), names 
				
			restore
			
		
		*Traditional Forgiveness Measure w Interest Forgiven
		*sset scheme dark2 
		graph hbox total_trad_forgiven if prog_tag [aw=stu_count], ///
			over(pass_zone_fail) noout ytitle("Amount in Dollars") ///
			yline(0) yline(20000) yline(40000) xtick()
			
			graph export "${ge_data}trad_forgiveness_w_int.png", replace
			
			*Add Plot to Spreadsheet
			putexcel set "${ge_data}artready_figures_ge_idr_3.xlsx", sheet("Figure 2") modify
			putexcel B6 = picture("${ge_data}trad_forgiveness_w_int.png")
			
		
		*Amount Repaid vs. 10yr Standard 
		*set scheme set1 
		graph hbox fav_dif unfav_dif if prog_tag [aw=stu_count], noout over(pass_zone_fail) ///
			legend(label(1 "Discount Rate = 2.8%") label(2 "Discount Rate = 5%")) ///
			ytitle("Amount in Dollars") yline(0) yline(-10000) yline(-20000) yline(-30000) yline(10000)
		
			graph export "${ge_data}dif_amount_repaid_by_disc_rate.png", replace 
			
			*Add Plot to Spreadsheet
			putexcel set "${ge_data}artready_figures_ge_idr_3.xlsx", sheet("Figure 3") modify
			
			putexcel B5 = picture("${ge_data}principal_paydown_by_program_medians_comb.png")
		
			putexcel B2 = ("Figure 2") 
			putexcel B2, bold
			
			putexcel B3 = ("Failing and Zone Programs Likely to Have A Great Deal of Debt Forgiven")
			putexcel B4 = (" Distribution of total principal and interest left at forgiveness time by program status") 
			
			putexcel B26 = ("Note:  All values in nominal terms. Distributions are student-weighted. Outliers not pictured. The leftmost end of each whisker represents the lower adjacent value, while the rightmost is the upper-adjacent value. The lower adjacent value equals the smallest observation greater than or equal to the first quartile minus one and half times the interquartile range. Similarly, the upper adjacent value is the largest observation less than or equal to the third quartile plus one and half times the interquartile range.") 
			
			
			putexcel B6 = picture("${ge_data}dif_amount_repaid_by_disc_rate.png")
			
		
		
		*******************
		*** Cost to Gov't Total
		*******************
		*Create a tag on one observation in each of the Pass-Zone-and-Fail programs
		egen pzf_tag = tag(pass_zone_fail) 
		
		preserve 
		
		
		forvalues i = .01(.01)1.01{
		
			local count_100 = round(`i'*100)
		
			di "i: `i' , count_100: `count_100'" 
		
			gen idr_enrolled_count_`count_100' = round(stu_count*`i')
			
			gen prog_tot_cost_fav_`count_100' = fav_dif*idr_enrolled_count_`count_100'
			
			gen prog_tot_cost_unfav_`count_100' = unfav_dif*idr_enrolled_count_`count_100'
		
			
		}
		
		
		*tabstat total_prog_cost_fav_50
		save "${ge_data}idr_par_sweeps.dta", replace
		
		*/
		
		use "${ge_data}idr_par_sweeps.dta", replace
	
			 
		tabstat prog_tot_cost_fav_25 prog_tot_cost_unfav_25 ///
			 prog_tot_cost_fav_50 prog_tot_cost_unfav_50 ///
			 prog_tot_cost_fav_75 prog_tot_cost_unfav_75 ///
			 prog_tot_cost_fav_100 prog_tot_cost_unfav_100 if prog_tag, ///
			 stat(sum) by(pass_zone_fail) save 
		
		tabstatmat total_cost 
		
		tabstat stu_count if prog_tag & pass_zone_fail!="Passing" & !missing(pass_zone_fail), ///
			 stat(sum) by(pass_zone_fail) save 
		
		putexcel set "${ge_data}artready_figures_ge_idr_3.xlsx", sheet("Appendix Table 1") modify
		
		
		putexcel C7 = matrix(total_cost)
		
		putexcel B7 = ("Failing")
		putexcel B8 = ("In Zone")
		putexcel B9 = ("Passing") 
		putexcel B10 = ("Total") 
		
		putexcel B4 = ("The Total Repayment Gap, by IDR Enrollment Assumptions")
		
		putexcel C5 = ("Total Gap, 25% IDR Enrollment")
		putexcel E5 = ("Total Gap, 50% IDR Enrollment")
		putexcel G5 = ("Total Gap, 75% IDR Enrollment")
		putexcel I5 = ("Total Gap, 100% IDR Enrollment")
		
		putexcel C6 = ("2.8% Discount Rate")
		putexcel D6 = ("5% Discount Rate")
		putexcel E6 = ("2.8% Discount Rate")
		putexcel F6 = ("5% Discount Rate")
		putexcel G6 = ("2.8% Discount Rate")
		putexcel H6 = ("5% Discount Rate")
		putexcel I6 = ("2.8% Discount Rate")
		putexcel J6 = ("5% Discount Rate")
		
		
		
			tabstat prog_tot_cost_fav_50 prog_tot_cost_unfav_50 ///
			 if prog_tag & pass_zone_fail!="Passing" & !missing(pass_zone_fail), stat(sum) save 
			
			mat m = r(StatTotal)
			
			
			tabstat prog_tot_cost_fav_50 prog_tot_cost_unfav_50 ///
			 if prog_tag & pass_zone_fail=="Passing", stat(sum) save 
			
			mat n = r(StatTotal)
			
		
		putexcel set "${ge_data}artready_figures_ge_idr_3.xlsx", sheet("In-text references") modify
		
				
			*Store the total for Passing programs with .028 discount 
				putexcel C8 = (m[1,1]) 
			
			*Store the total for Non-passing programs with .028 discount 
				putexcel C7 = (n[1,1]) 
			
			*Store the total for Passing programs with .05 discount
				putexcel C13 = (m[1,2]) 
			
			*Store the total for Non-passing programs with .05 discount
				putexcel C12 = (n[1,2]) 
		
		restore
		
		
		**********
		
		********* Output some key stats 
		
			*Set up info: 
			putexcel set "${ge_data}artready_figures_ge_idr_3.xlsx", sheet("In-text references") modify
			
			
			putexcel B2 = ("Numbers that do not appear in a table or figure but that we calculated and are referenced in the text appear here")
			
			putexcel B6:C6, bold
			putexcel B6 = ("Discount rate: 2.8%") 
			putexcel C6 = ("Total Repayment Deficit from IDR Usage By Status") 
			
			putexcel B7 = ("Passing Programs") 
			putexcel B8 = ("Non-passing Programs") 
			
			
			putexcel B11:C11, bold
			putexcel B11 = ("Discount rate: 5%") 
			putexcel C11 = ("Total Unpaid Loan Cost of Programs") 
			
			putexcel B12 = ("Passing Programs") 
			putexcel B13 = ("Non-passing Programs") 
			
			
			putexcel B16, bold 
			putexcel B16 = ("Median income for grads of non-passing programs & $10,000 as a percentage of that amount")
			putexcel B17 = ("Median typical income in GE data") 
			
			*putexcel C19 =  nformat(%)
			putexcel B19, bold
			putexcel B19 = ("% Income Increase Required") 
			
			putexcel B21, bold
			putexcel B21 = ("Typical forgiveness amount for non-passing programs") 
			
			putexcel B22 = ("Nominal") 
			putexcel B23 = ("2.8% discount rate") 
			putexcel B24 = ("5% discount rate") 
				
			
			*Mean income among non-passing programs
			sum med_earnings_orig if year==3 & month==1 & ///
				pass_zone_fail!="Passing" & !missing(pass_zone_fail) [aw=stu_count], d
				
			putexcel set "${ge_data}artready_figures_ge_idr_3.xlsx", sheet("In-text references") modify
			putexcel C17 = `r(p50)' 
			putexcel C18 = (10000) 
			
			
			*Median forgiveness amount (nominal)
			sum total_trad_forgiven if prog_tag & pass_zone_fail=="Failing" ///
				[aw=stu_count], d 
			
			sum total_trad_forgiven if prog_tag & non_pass_prog ///
				[aw=stu_count], d 
				
			putexcel set "${ge_data}artready_figures_ge_idr_3.xlsx", sheet("In-text references") modify
			putexcel C22 = `r(p50)' 
				
			*Median forgiveness amount (discount 2.8%)
			gen act_total_int_princ_left_fav =  act_total_int_princ_left/((1+(`discount_rate_fav'))^max_year) + tot_monthly_int_forg_fav
			
			sum act_total_int_princ_left_fav if prog_tag & non_pass_prog ///
				[aw=stu_count], d 
			
			putexcel set "${ge_data}artready_figures_ge_idr_3.xlsx", sheet("In-text references") modify
			putexcel C23 = `r(p50)' 
			
			*Mean forgiveness amount (discount 5%)
			gen act_total_int_princ_left_unfav = act_total_int_princ_left/((1+(`discount_rate_unfav'))^max_year) + tot_monthly_int_forg_unfav
			
			sum act_total_int_princ_left_unfav if prog_tag & non_pass_prog ///
				[aw=stu_count], d 
			
			putexcel set "${ge_data}artready_figures_ge_idr_3.xlsx", sheet("In-text references") modify
			putexcel C24 = `r(p50)' 
			
			*Proportion of Programs Paying off 
			tabstat act_payoff_year_sum if prog_tag [aw=stu_count], stat(mean) by(pass_zone_fail) save 
			tabstatmat A, nototal
				
			putexcel set "${ge_data}artready_figures_ge_idr_3.xlsx", sheet("In-text references") modify
			
				putexcel C27 = matrix(A)
				
				putexcel B26, bold
				
				putexcel B27 = ("Failing")
				putexcel B28 = ("In Zone") 
				putexcel B29 = ("Passing") 
				
				putexcel B26 = ("Percentage of programs paying off in full") 
				
		*****Find the relevant stats that correpsond to the graphs*************
			*Automate export to excel spreadsheet
		
		*Start with differences between the two amounts paid back between standard & REPAYE
		local variables fav_dif unfav_dif 
			
			
		// Create an empty matrix y with J rows and K columns based on the number of variables of interest and 
		//	 the number of summary statistic scalars that you wish to report

		local j_rows=6
		local k_columns=5

		mat m = J(`j_rows',`k_columns',.)

		// Initialize counter variable y to start at 1

		local y=1

		
		// Generate matrix of summary statistics fromt he pre-specified list of variables
		
		*Loop through program statuses
		foreach status in "Failing" "In Zone" "Passing"{
		
			*Loop through the favorable and unfavorable discount values for principal and repayment differences
			foreach var of varlist `variables' {
		
				di "Var: `var' Status: `status'"
					
				*Calculate the 25th 50th & 75th percentiles for each program status 
				sum `var' if prog_tag & pass_zone_fail=="`status'" [aw=stu_count], d
					
					
					*Store the percentile values in columns 2, 3, and 4 of the matrix
					mat m[`y',2] = round(r(p25),.1)
					
					mat m[`y',3] = round(r(p50),.1)
				
					mat m[`y',4] = round(r(p75),.1)
					
				*Calculate upper & lower inner fences using above data
				local u = r(p75) + (3/2) * (r(p75) - r(p25))
				local l = r(p25) - (3/2) * (r(p75) - r(p25))
				
				*Calculate upper and lower adjacent values using fence values, store them in colums 1 & 5 of matrix
				sum `var' if prog_tag & pass_zone_fail=="`status'" & `var' >= `l' [aw=stu_count], meanonly
				
					mat m[`y',1] = round(r(min), .1)  
								
				sum `var' if prog_tag & pass_zone_fail=="`status'" & `var' <= `u' [aw=stu_count], meanonly
				
					mat m[`y',5] = round(r(max), .1)  
					
				*Increment our counter
				local y=`y'+1
				
	
			}
		}

		// Name Columns and Rows
		mat colnames m = "LAV" "25th" "Median" "75th" "UAV" 
		mat rownames m = "Failing, 2.8%" "Failing, 5%" "In the Zone, 2.8%" "In the Zone, 5%" "Passing, 2.8%" "Passing, 5%" 
							
		
		*Next store differences between the amount paid back & original principal 
		local reg_forgiveness total_trad_forgiven 
		
		
		// Create an empty matrix y with J rows and K columns based on the number of variables of interest and 
		//	 the number of summary statistic scalars that you wish to report

		local j_rows=6
		local k_columns=5

		mat n = J(`j_rows',`k_columns',.)

		// Initialize counter variable y to start at 1

		local y=1

		
		// Generate matrix of summary statistics fromt he pre-specified list of variables
		
		*Loop through program statuses
		foreach status in "Failing" "In Zone" "Passing"{
		
			*Loop through the favorable and unfavorable discount values for principal and repayment differences
			foreach var of varlist `reg_forgiveness' {
		
				di "Var: `var' Status: `status'"
					
				*Calculate the 25th 50th & 75th percentiles for each program status 
				sum `var' if prog_tag & pass_zone_fail=="`status'" [aw=stu_count], d
					
					
					*Store the percentile values in columns 2, 3, and 4 of the matrix
					mat n[`y',2] = round(r(p25),.1)
					
					mat n[`y',3] = round(r(p50),.1)
				
					mat n[`y',4] = round(r(p75),.1)
					
				*Calculate upper & lower inner fences using above data
				local u = r(p75) + (3/2) * (r(p75) - r(p25))
				local l = r(p25) - (3/2) * (r(p75) - r(p25))
				
				*Calculate upper and lower adjacent values using fence values, store them in colums 1 & 5 of matrix
				sum `var' if prog_tag & pass_zone_fail=="`status'" & `var' >= `l' [aw=stu_count], meanonly
				
					mat n[`y',1] = round(r(min), .1)  
								
				sum `var' if prog_tag & pass_zone_fail=="`status'" & `var' <= `u' [aw=stu_count], meanonly
				
					mat n[`y',5] = round(r(max), .1)  
					
				*Increment our counter
				local y=`y'+1
				
	
			}
		}

		// Name Columns and Rows
		mat colnames n = "LAV" "25th" "Median" "75th" "UAV" 
		mat rownames n = "Failing" "In the Zone" "Passing" " " " " " " 
										
		// Save matrices to spreadsheet
		putexcel set "${ge_data}artready_figures_ge_idr_3.xlsx", sheet("Figure 3") modify
		
			putexcel B2 = ("Figure 3") 
			putexcel B2, bold
			
			putexcel B3 = ("For students at failing and zone programs, using the income-driven repayment safety net means paying more over the life of their loan")
			putexcel B4 = ("The below graph shows the amount a student with typical earnings and debt would repay under a standard 10-year plan minus amount they would repay under REPAYE") 
			
			putexcel B26 = ("Note: Outliers not pictured. The repayment gap is defined as the amount a student would repay under the plan with the cheapest monthly payment option (between REPAYE and the 10-year standard) minus the amount repaid under the 10-year standard plan. Negative numbers imply a student repays less under REPAYE than under the 10yr standard plan, while positive numbers imply a student repays less under the standard payment. All payment amounts discounted to when a student enters repayment. We discount each monthly payment as it is received, rather than discounting the total amount received at the beginning or end of the year as some agencies do. The leftmost end of each whisker represents the lower adjacent value, while the rightmost is the upper-adjacent value. The lower adjacent value equals the smallest observation greater than or equal to the first quartile minus one and half times the interquartile range. Similarly, the upper adjacent value is the largest observation less than or equal to the third quartile plus one and half times the interquartile range.")
			
			
			putexcel B6 = picture("${ge_data}dif_amount_repaid_by_disc_rate.png")
			
			putexcel N8 = matrix(m), names 
		
		putexcel set "${ge_data}artready_figures_ge_idr_3.xlsx", sheet("Figure 2") modify
			
			putexcel N8 = matrix(n), names 
		
		timer off 1
		
		log close
		translate "${ge_data}CAP_ge_log.smcl" "${ge_data}CAP_ge_log.pdf", replace 
		
